#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

test_1 = {
    "Category:21st-century New Zealand non-fiction writers": "تصنيف:كتاب غير روائيين نيوزيلنديون في القرن 21",
    "Category:20th-century New Zealand non-fiction writers": "تصنيف:كتاب غير روائيين نيوزيلنديون في القرن 20",
    "Category:New Zealand non-fiction writers": "تصنيف:كتاب غير روائيين نيوزيلنديون",
    "Category:New Zealand non-fiction writers by century": "تصنيف:كتاب غير روائيين نيوزيلنديون حسب القرن",
    "Category:New Zealand non-fiction books": "تصنيف:كتب نيوزيلندية غير خيالية",
}

data_empty_result = {
    "Category:Academicians of non-governmental academies based in Russia": "x",
    "Category:Advisory non-departmental public bodies of the Scottish Government": "x",
    "Category:AfC submissions declined as a non-notable academic topic": "x",
    "Category:AfC submissions declined as a non-notable athletic topic": "x",
    "Category:AfC submissions declined as a non-notable biography": "x",
    "Category:AfC submissions declined as a non-notable book": "x",
    "Category:AfC submissions declined as a non-notable event": "x",
    "Category:AfC submissions declined as a non-notable film": "x",
    "Category:AfC submissions declined as a non-notable musical topic": "x",
    "Category:AfC submissions declined as a non-notable organization": "x",
    "Category:AfC submissions declined as non-notable web content": "x",
    "Category:AfC submissions declined as non-notable": "x",
    "Category:AfC submissions rejected as non-notable": "x",
    "Category:Africa territory (non-sovereign) templates": "x",
    "Category:Akron Firestone Non-Skids coaches": "x",
    "Category:Akron Firestone Non-Skids players": "x",
    "Category:Akron Firestone Non-Skids seasons": "x",
    "Category:Akron Firestone Non-Skids": "x",
    "Category:Album articles with non-standard infoboxes": "x",
    "Category:All articles with improper non-free content": "x",
    "Category:All non-free logos": "x",
    "Category:All non-free media": "x",
    "Category:American non-commissioned personnel": "x",
    "Category:Animal testing on non-human primates": "x",
    "Category:Anthems of non-sovereign states": "x",
    "Category:Articles containing Bantayanon-language text": "x",
    "Category:Articles containing Bantoanon-language text": "x",
    "Category:Articles containing Butuanon-language text": "x",
    "Category:Articles containing Capiznon-language text": "x",
    "Category:Articles containing Cuyonon-language text": "x",
    "Category:Articles containing Higaonon-language text": "x",
    "Category:Articles containing Hiligaynon-language text": "x",
    "Category:Articles containing Malaynon-language text": "x",
    "Category:Articles containing non-English-language text": "x",
    "Category:Articles containing Northern Sorsoganon-language text": "x",
    "Category:Articles containing Ratagnon-language text": "x",
    "Category:Articles containing Romblomanon-language text": "x",
    "Category:Articles containing Southern Sorsoganon-language text": "x",
    "Category:Articles containing Surigaonon-language text": "x",
    "Category:Articles containing Tandaganon-language text": "x",
    "Category:Articles containing Western Subanon-language text": "x",
    "Category:Articles needing non-English script or text": "x",
    "Category:Articles with excessive non-free audio content": "x",
    "Category:Articles with improper non-free content": "x",
    "Category:Articles with non-English-language CS1 sources": "x",
    "Category:Articles with non-English-language sources": "x",
    "Category:Articles with non-HTML file bare URLs for citations": "x",
    "Category:Asia territory (non-sovereign) templates": "x",
    "Category:Association football player non-biographical articles": "x",
    "Category:Australian non-commissioned personnel": "x",
    "Category:Bollywood Hungama movie template using non-numeric ID": "x",
    "Category:Bollywood Hungama person template using non-numeric ID": "x",
    "Category:Bosnia and Herzegovina non-alcoholic drinks": "x",
    "Category:British non-commissioned personnel": "x",
    "Category:Buddhism articles needing non-English scripting support & specialist attention": "x",
    "Category:Candidates for speedy deletion as dependent on a non-existent page": "x",
    "Category:Cannon-launched guided projectiles": "x",
    "Category:Chairpersons of non-governmental organizations": "x",
    "Category:Chinese people by non-city prefecture-level division": "x",
    "Category:Christian non-aligned Scouting organizations": "x",
    "Category:Citation Style 1 templates using non-standard parameters": "x",
    "Category:Class masks with non-standard classes": "x",
    "Category:Closed non-builders": "x",
    "Category:Club of Committed Non-Party Members politicians": "x",
    "Category:Coats of arms of non-metropolitan district councils": "x",
    "Category:Cometary object redirects (non-primary)": "x",
    "Category:Completed non-free use rationale logo transclusions": "x",
    "Category:Conversion of non-Christian religious buildings and structures into churches": "x",
    "Category:Cue sports articles with good non-English versions": "x",
    "Category:Deaths from non-Hodgkin lymphoma": "x",
    "Category:Defunct non-departmental public bodies of the United Kingdom government": "x",
    "Category:Defunct non-English-language newspapers published in the United States": "x",
    "Category:Drugs with non-standard legal status": "x",
    "Category:Drugs with non-standard pregnancy category": "x",
    "Category:Editnotices with unsalted non-existent targets": "x",
    "Category:Educational technology non-profits": "x",
    "Category:English non-league football articles by importance": "x",
    "Category:English non-league football articles by quality": "x",
    "Category:English non-League football club squad templates": "x",
    "Category:English non-league football task force articles": "x",
    "Category:English non-league football task force": "x",
    "Category:English non-league team of the year navigational boxes": "x",
    "Category:Episode lists with a non-matching set of numbered parameters": "x",
    "Category:Episode lists with non-compliant line colors": "x",
    "Category:Europe territory (non-sovereign) templates": "x",
    "Category:Executive non-departmental public bodies of the Scottish Government": "x",
    "Category:Experimental drugs developed for non-alcoholic fatty liver disease": "x",
    "Category:Experimental non-hallucinogens": "x",
    "Category:Fiction redirect categories with non-existent parent categories": "x",
    "Category:Fictional non-commissioned officers": "x",
    "Category:Fictional United States Army non-commissioned officers": "x",
    "Category:First secretaries in non-national subdivisions of the Soviet Union": "x",
    "Category:FootballFacts.ru template using non-numeric ID": "x",
    "Category:Former evangelical non-denominational churches": "x",
    "Category:Former non-metropolitan counties": "x",
    "Category:Former non-metropolitan district councils of England": "x",
    "Category:Former non-metropolitan districts of Avon": "x",
    "Category:Former non-metropolitan districts of Bedfordshire": "x",
    "Category:Former non-metropolitan districts of Buckinghamshire": "x",
    "Category:Former non-metropolitan districts of Cheshire": "x",
    "Category:Former non-metropolitan districts of Cornwall": "x",
    "Category:Former non-metropolitan districts of Cumbria": "x",
    "Category:Former non-metropolitan districts of Dorset": "x",
    "Category:Former non-metropolitan districts of Durham": "x",
    "Category:Former non-metropolitan districts of East Sussex": "x",
    "Category:Former non-metropolitan districts of Hereford and Worcester": "x",
    "Category:Former non-metropolitan districts of Humberside": "x",
    "Category:Former non-metropolitan districts of Kent": "x",
    "Category:Former non-metropolitan districts of North Yorkshire": "x",
    "Category:Former non-metropolitan districts of Northamptonshire": "x",
    "Category:Former non-metropolitan districts of Northumberland": "x",
    "Category:Former non-metropolitan districts of Shropshire": "x",
    "Category:Former non-metropolitan districts of Somerset": "x",
    "Category:Former non-metropolitan districts of Suffolk": "x",
    "Category:Former non-metropolitan districts of the Isle of Wight": "x",
    "Category:Former non-metropolitan districts of Wiltshire": "x",
    "Category:Former non-metropolitan districts": "x",
    "Category:Formula One non-championship races": "x",
    "Category:Hash function (non-cryptographic)": "x",
    "Category:Heads of government of non-sovereign entities": "x",
    "Category:High-importance English non-league football articles": "x",
    "Category:High-importance Non-tropical storm articles": "x",
    "Category:Hockey Australia template using non-numeric ID": "x",
    "Category:Idioms from non-English cultures": "x",
    "Category:Infobox drug articles with non-default infobox title": "x",
    "Category:Infobox rugby biography with non-numeric numeric parameters": "x",
    "Category:Infobox U.S. county using a non-standard time zone": "x",
    "Category:Infobox U.S. county using a non-standard timezone": "x",
    "Category:International Emmy Award for Best Non-Scripted Entertainment winners": "x",
    "Category:Irish non-subscribing Presbyterian ministers": "x",
    "Category:Japan in non-Japanese culture": "x",
    "Category:Jctint template using non-numeric parameter values": "x",
    "Category:Law enforcement non-governmental organizations in the United States": "x",
    "Category:Leaders of the Non-Partisan Solidarity Union": "x",
    "Category:Lists by population (non-human)": "x",
    "Category:Lists of aircraft in non-standard formats": "x",
    "Category:Lists of non-sovereign nations": "x",
    "Category:Low-importance English non-league football articles": "x",
    "Category:Low-importance Non-tropical storm articles": "x",
    "Category:Metropolitan and non-metropolitan counties": "x",
    "Category:Mid-importance English non-league football articles": "x",
    "Category:Mid-importance Non-tropical storm articles": "x",
    "Category:Minor planet object redirects (non-primary)": "x",
    "Category:Monthly clean-up category (Articles with improper non-free content) counter": "x",
    "Category:Montreal Shamrocks (non-NHA) players": "x",
    "Category:Non-Aggression Pact (band) albums": "x",
    "Category:Non-aggression pacts": "x",
    "Category:Non-alcoholic drink logos": "x",
    "Category:Non-alcoholic drinks": "x",
    "Category:Non-alcoholic fatty liver disease": "x",
    "Category:Non-alcoholic mixed drinks": "x",
    "Category:Non-Aligned Movement people": "x",
    "Category:Non-Aligned Movement Summits": "x",
    "Category:Non-Aligned Movement": "x",
    "Category:Non-aligned Scouting organizations in Canada": "x",
    "Category:Non-aligned Scouting organizations in the United States": "x",
    "Category:Non-aligned Scouting organizations": "x",
    "Category:Non-alternating knots and links": "x",
    "Category:Non-Arab companions of the Prophet": "x",
    "Category:Non-Arabic-language mass media in Algeria": "x",
    "Category:Non-Arabic-language mass media in Egypt": "x",
    "Category:Non-Arabic-language mass media in Lebanon": "x",
    "Category:Non-Arabic-language mass media in Morocco": "x",
    "Category:Non-Arabic-language mass media in Tunisia": "x",
    "Category:Non-Arabic-language newspapers published in Algeria": "x",
    "Category:Non-Arabic-language newspapers published in Egypt": "x",
    "Category:Non-Arabic-language newspapers published in Lebanon": "x",
    "Category:Non-Arabic-language newspapers published in Morocco": "x",
    "Category:Non-Arabic-language newspapers published in Tunisia": "x",
    "Category:Non-articles using infobox website with unknown parameters": "x",
    "Category:Non-associative algebra": "x",
    "Category:Non-associative algebras": "x",
    "Category:Non-benzenoid aromatic carbocycles": "x",
    "Category:Non-British Royal Air Force personnel of World War II": "x",
    "Category:Non-cabinet ministers of Sri Lanka": "x",
    "Category:Non-canon Doctor Who episodes": "x",
    "Category:Non-cardinals elected pope": "x",
    "Category:Non-Chalcedonian Christians": "x",
    "Category:Non-Chalcedonianism": "x",
    "Category:Non-cinematic Western (genre) films": "x",
    "Category:Non-citizen suffrage": "x",
    "Category:Non-clerical religious clothing": "x",
    "Category:Non-coding DNA": "x",
    "Category:Non-coding RNA": "x",
    "Category:Non-combat internal explosions on warships": "x",
    "Category:Non-combat naval accidents of the United States": "x",
    "Category:Non-combat naval accidents": "x",
    "Category:Non-combatant evacuation operations": "x",
    "Category:Non-combatant military personnel of the American Civil War": "x",
    "Category:Non-combatant military personnel": "x",
    "Category:Non-commercial": "x",
    "Category:Non-commissioned air force personnel": "x",
    "Category:Non-commissioned army personnel": "x",
    "Category:Non-commissioned officers": "x",
    "Category:Non-commissioned personnel": "x",
    "Category:Non-conformist Sunni jurisprudence": "x",
    "Category:Non-conformists of the 1550s": "x",
    "Category:Non-conformists": "x",
    "Category:Non-cooperative games": "x",
    "Category:Non-coordinating anions": "x",
    "Category:Non-dairy yogurts": "x",
    "Category:Non-Darwinian evolution": "x",
    "Category:Non-deaf sign languages": "x",
    "Category:Non-denominational Evangelical churches in the United States": "x",
    "Category:Non-denominational Evangelical churches": "x",
    "Category:Non-denominational Evangelical multisite churches in the United States": "x",
    "Category:Non-denominational Evangelical multisite churches": "x",
    "Category:Non-denominational Evangelical unions": "x",
    "Category:Non-denominational Judaism": "x",
    "Category:Non-departmental public bodies of the Northern Ireland Executive": "x",
    "Category:Non-departmental public bodies of the United Kingdom government": "x",
    "Category:Non-diocesan Anglican bishops": "x",
    "Category:Non-Disney Mickey Mouse-media": "x",
    "Category:Non-dynastic kings of Macedonia (ancient kingdom)": "x",
    "Category:Non-dynastic pharaohs": "x",
    "Category:Non-empty disambiguation categories": "x",
    "Category:Non-English user warning templates": "x",
    "Category:Non-English welcome messages": "x",
    "Category:Non-English works based on the Encyclopædia Britannica": "x",
    "Category:Non-English-based programming languages": "x",
    "Category:Non-English-language broadcasting in the United States": "x",
    "Category:Non-English-language magazines published in the United Kingdom": "x",
    "Category:Non-English-language magazines published in the United States": "x",
    "Category:Non-English-language mass media in Alabama": "x",
    "Category:Non-English-language mass media in Arizona": "x",
    "Category:Non-English-language mass media in Arkansas": "x",
    "Category:Non-English-language mass media in California": "x",
    "Category:Non-English-language mass media in Colorado": "x",
    "Category:Non-English-language mass media in Connecticut": "x",
    "Category:Non-English-language mass media in Delaware": "x",
    "Category:Non-English-language mass media in Florida": "x",
    "Category:Non-English-language mass media in Georgia (U.S. state)": "x",
    "Category:Non-English-language mass media in Hawaii": "x",
    "Category:Non-English-language mass media in Illinois": "x",
    "Category:Non-English-language mass media in Indiana": "x",
    "Category:Non-English-language mass media in Iowa": "x",
    "Category:Non-English-language mass media in Kansas": "x",
    "Category:Non-English-language mass media in Kentucky": "x",
    "Category:Non-English-language mass media in Louisiana": "x",
    "Category:Non-English-language mass media in Maine": "x",
    "Category:Non-English-language mass media in Maryland": "x",
    "Category:Non-English-language mass media in Massachusetts": "x",
    "Category:Non-English-language mass media in Michigan": "x",
    "Category:Non-English-language mass media in Minnesota": "x",
    "Category:Non-English-language mass media in Missouri": "x",
    "Category:Non-English-language mass media in Nebraska": "x",
    "Category:Non-English-language mass media in Nevada": "x",
    "Category:Non-English-language mass media in New Jersey": "x",
    "Category:Non-English-language mass media in New Mexico": "x",
    "Category:Non-English-language mass media in New York (state)": "x",
    "Category:Non-English-language mass media in North Carolina": "x",
    "Category:Non-English-language mass media in North Dakota": "x",
    "Category:Non-English-language mass media in Ohio": "x",
    "Category:Non-English-language mass media in Oklahoma": "x",
    "Category:Non-English-language mass media in Oregon": "x",
    "Category:Non-English-language mass media in Pennsylvania": "x",
    "Category:Non-English-language mass media in Rhode Island": "x",
    "Category:Non-English-language mass media in South Carolina": "x",
    "Category:Non-English-language mass media in South Dakota": "x",
    "Category:Non-English-language mass media in Tennessee": "x",
    "Category:Non-English-language mass media in Texas": "x",
    "Category:Non-English-language mass media in the United Kingdom": "x",
    "Category:Non-English-language mass media in the United States by state": "x",
    "Category:Non-English-language mass media in the United States": "x",
    "Category:Non-English-language mass media in Utah": "x",
    "Category:Non-English-language mass media in Virginia": "x",
    "Category:Non-English-language mass media in Washington (state)": "x",
    "Category:Non-English-language mass media in Wisconsin": "x",
    "Category:Non-English-language newspapers published in Arizona": "x",
    "Category:Non-English-language newspapers published in Australia": "x",
    "Category:Non-English-language newspapers published in California": "x",
    "Category:Non-English-language newspapers published in Colorado": "x",
    "Category:Non-English-language newspapers published in Connecticut": "x",
    "Category:Non-English-language newspapers published in Florida": "x",
    "Category:Non-English-language newspapers published in Georgia (U.S. state)": "x",
    "Category:Non-English-language newspapers published in Illinois": "x",
    "Category:Non-English-language newspapers published in Iowa": "x",
    "Category:Non-English-language newspapers published in Kansas": "x",
    "Category:Non-English-language newspapers published in Louisiana": "x",
    "Category:Non-English-language newspapers published in Maine": "x",
    "Category:Non-English-language newspapers published in Maryland": "x",
    "Category:Non-English-language newspapers published in Massachusetts": "x",
    "Category:Non-English-language newspapers published in Michigan": "x",
    "Category:Non-English-language newspapers published in Minnesota": "x",
    "Category:Non-English-language newspapers published in Missouri": "x",
    "Category:Non-English-language newspapers published in Nebraska": "x",
    "Category:Non-English-language newspapers published in Nevada": "x",
    "Category:Non-English-language newspapers published in New Jersey": "x",
    "Category:Non-English-language newspapers published in New Mexico": "x",
    "Category:Non-English-language newspapers published in New York (state)": "x",
    "Category:Non-English-language newspapers published in North Carolina": "x",
    "Category:Non-English-language newspapers published in North Dakota": "x",
    "Category:Non-English-language newspapers published in Ohio": "x",
    "Category:Non-English-language newspapers published in Oregon": "x",
    "Category:Non-English-language newspapers published in Pennsylvania": "x",
    "Category:Non-English-language newspapers published in South Dakota": "x",
    "Category:Non-English-language newspapers published in Texas": "x",
    "Category:Non-English-language newspapers published in the United States by state": "x",
    "Category:Non-English-language newspapers published in the United States": "x",
    "Category:Non-English-language newspapers published in Washington (state)": "x",
    "Category:Non-English-language newspapers published in Wisconsin": "x",
    "Category:Non-English-language radio stations in Alabama": "x",
    "Category:Non-English-language radio stations in Arizona": "x",
    "Category:Non-English-language radio stations in Arkansas": "x",
    "Category:Non-English-language radio stations in California": "x",
    "Category:Non-English-language radio stations in Colorado": "x",
    "Category:Non-English-language radio stations in Connecticut": "x",
    "Category:Non-English-language radio stations in Delaware": "x",
    "Category:Non-English-language radio stations in Florida": "x",
    "Category:Non-English-language radio stations in Georgia (U.S. state)": "x",
    "Category:Non-English-language radio stations in Hawaii": "x",
    "Category:Non-English-language radio stations in Illinois": "x",
    "Category:Non-English-language radio stations in Indiana": "x",
    "Category:Non-English-language radio stations in Kansas": "x",
    "Category:Non-English-language radio stations in Kentucky": "x",
    "Category:Non-English-language radio stations in Louisiana": "x",
    "Category:Non-English-language radio stations in Maryland": "x",
    "Category:Non-English-language radio stations in Massachusetts": "x",
    "Category:Non-English-language radio stations in Minnesota": "x",
    "Category:Non-English-language radio stations in Missouri": "x",
    "Category:Non-English-language radio stations in New Jersey": "x",
    "Category:Non-English-language radio stations in New Mexico": "x",
    "Category:Non-English-language radio stations in New York (state)": "x",
    "Category:Non-English-language radio stations in North Carolina": "x",
    "Category:Non-English-language radio stations in Ohio": "x",
    "Category:Non-English-language radio stations in Oklahoma": "x",
    "Category:Non-English-language radio stations in Oregon": "x",
    "Category:Non-English-language radio stations in Pennsylvania": "x",
    "Category:Non-English-language radio stations in Rhode Island": "x",
    "Category:Non-English-language radio stations in South Carolina": "x",
    "Category:Non-English-language radio stations in Tennessee": "x",
    "Category:Non-English-language radio stations in Texas": "x",
    "Category:Non-English-language radio stations in the United States by state": "x",
    "Category:Non-English-language radio stations in Utah": "x",
    "Category:Non-English-language radio stations in Washington (state)": "x",
    "Category:Non-English-language radio stations in Wisconsin": "x",
    "Category:Non-English-language television stations in California": "x",
    "Category:Non-English-language television stations in Florida": "x",
    "Category:Non-Euclidean geometry": "x",
    "Category:Non-fatal shootings": "x",
    "Category:Non-ferrous metallurgical works in the United Kingdom": "x",
    "Category:Non-FIFA football competitions": "x",
    "Category:Non-food crop diseases": "x",
    "Category:Non-food crops": "x",
    "Category:Non-free Analog Science Fiction and Fact magazine covers": "x",
    "Category:Non-free architectural works": "x",
    "Category:Non-free audio samples by artist": "x",
    "Category:Non-free bandy logos": "x",
    "Category:Non-free Black Mask magazine covers": "x",
    "Category:Non-free character artwork": "x",
    "Category:Non-free computer icons": "x",
    "Category:Non-free destroyed architecture": "x",
    "Category:Non-free Disney logos": "x",
    "Category:Non-free Dragon magazine covers": "x",
    "Category:Non-free Dungeon magazine covers": "x",
    "Category:Non-free Entertainment Weekly magazine covers": "x",
    "Category:Non-free Esquire magazine covers": "x",
    "Category:Non-free Fantastic Universe magazine covers": "x",
    "Category:Non-free Far Eastern Economic Review magazine covers": "x",
    "Category:Non-free former or old logos": "x",
    "Category:Non-free Fortune magazine covers": "x",
    "Category:Non-free Galaxy Science Fiction magazine covers": "x",
    "Category:Non-free GQ magazine covers": "x",
    "Category:Non-free graffiti with NFUR stated": "x",
    "Category:Non-free graffiti": "x",
    "Category:Non-free Heavy Metal magazine covers": "x",
    "Category:Non-free Life magazine covers": "x",
    "Category:Non-free logos": "x",
    "Category:Non-free Maclean's magazine covers": "x",
    "Category:Non-free Mad magazine covers": "x",
    "Category:Non-free magazine covers by title": "x",
    "Category:Non-free magazine covers": "x",
    "Category:Non-free media with non-commercial and no derivative works licenses": "x",
    "Category:Non-free Men's Health magazine covers": "x",
    "Category:Non-free music samples": "x",
    "Category:Non-free musical interface audio": "x",
    "Category:Non-free Mystery Scene magazine covers": "x",
    "Category:Non-free National Geographic magazine covers": "x",
    "Category:Non-free newspaper covers": "x",
    "Category:Non-free Newsweek magazine covers": "x",
    "Category:Non-free Penthouse magazine covers": "x",
    "Category:Non-free People magazine covers": "x",
    "Category:Non-free pictures of tornadoes": "x",
    "Category:Non-free Playbill magazine covers": "x",
    "Category:Non-free Playboy magazine covers": "x",
    "Category:Non-free Popular Electronics magazine covers": "x",
    "Category:Non-free posters": "x",
    "Category:Non-free proposed architecture": "x",
    "Category:Non-free Radio Times magazine covers": "x",
    "Category:Non-free rationale as na": "x",
    "Category:Non-free Redbook magazine covers": "x",
    "Category:Non-free Rolling Stone magazine covers": "x",
    "Category:Non-free school logos": "x",
    "Category:Non-free screenshots": "x",
    "Category:Non-free sheet music": "x",
    "Category:Non-free Sports Illustrated magazine covers": "x",
    "Category:Non-free Startling Stories magazine covers": "x",
    "Category:Non-free SVGs requiring file size reduction": "x",
    "Category:Non-free symbols": "x",
    "Category:Non-free The Atlantic magazine covers": "x",
    "Category:Non-free The Economist magazine covers": "x",
    "Category:Non-free The Magazine of Fantasy & Science Fiction magazine covers": "x",
    "Category:Non-free The New York Times Magazine magazine covers": "x",
    "Category:Non-free The New Yorker magazine covers": "x",
    "Category:Non-free The Saturday Evening Post magazine covers": "x",
    "Category:Non-free The Shadow magazine covers": "x",
    "Category:Non-free The Strand Magazine magazine covers": "x",
    "Category:Non-free Time magazine covers": "x",
    "Category:Non-free TV Guide magazine covers": "x",
    "Category:Non-free university technical college logos": "x",
    "Category:Non-free Unknown magazine covers": "x",
    "Category:Non-free use rationale templates": "x",
    "Category:Non-free Vanity Fair magazine covers": "x",
    "Category:Non-free Venture Science Fiction magazine covers": "x",
    "Category:Non-free video samples": "x",
    "Category:Non-free Vogue magazine covers": "x",
    "Category:Non-free Wired magazine covers": "x",
    "Category:Non-freeway toll roads": "x",
    "Category:Non-French-language magazines published in France": "x",
    "Category:Non-French-language newspapers published in France": "x",
    "Category:Non-fungible tokens": "x",
    "Category:Non-games": "x",
    "Category:Non-German units of the Wehrmacht": "x",
    "Category:Non-governmental academies based in Russia": "x",
    "Category:Non-governmental elections": "x",
    "Category:Non-governmental organizations": "x",
    "Category:Non-hallucinogenic 5-HT2A receptor agonists": "x",
    "Category:Non-Hebrew-language mass media in Israel": "x",
    "Category:Non-Hebrew-language newspapers published in Israel": "x",
    "Category:Non-Hodgkin lymphoma": "x",
    "Category:Non-human celestial navigation": "x",
    "Category:Non-human primate astronauts of the American space program": "x",
    "Category:Non-hunting areas of Thailand": "x",
    "Category:Non-idiophonic interruptive free aerophones": "x",
    "Category:Non-impact printing": "x",
    "Category:Non-Inscrits MEPs": "x",
    "Category:Non-institutional bodies of the European Union": "x",
    "Category:Non-international England cricketers": "x",
    "Category:Non-invented electrical components": "x",
    "Category:Non-ionic surfactants": "x",
    "Category:Non-Islamic Islam studies literature": "x",
    "Category:Non-ISO Language user templates": "x",
    "Category:Non-jamming knots": "x",
    "Category:Non-League football": "x",
    "Category:Non-lethal firearms of Russia": "x",
    "Category:Non-lethal firearms": "x",
    "Category:Non-lethal projectiles": "x",
    "Category:Non-lethal weapons": "x",
    "Category:Non-mainspace quotation templates": "x",
    "Category:Non-metropolitan district councils of England": "x",
    "Category:Non-military counterinsurgency organizations": "x",
    "Category:Non-military counterterrorist organizations": "x",
    "Category:Non-military rank insignia": "x",
    "Category:Non-ministerial departments of the Government of the United Kingdom": "x",
    "Category:Non-ministerial departments of the Scottish Government": "x",
    "Category:Non-ministerial departments of the Welsh Government": "x",
    "Category:Non-native Tamil poets": "x",
    "Category:Non-Neutral Independents politicians": "x",
    "Category:Non-Newtonian fluids": "x",
    "Category:Non-nucleophilic bases": "x",
    "Category:Non-nucleoside reverse transcriptase inhibitors": "x",
    "Category:Non-operating common carrier freight railroads in the United States": "x",
    "Category:Non-oxide glasses": "x",
    "Category:Non-Pama-Nyungan languages": "x",
    "Category:Non-parametric statistics": "x",
    "Category:Non-Partisan Association councillors": "x",
    "Category:Non-partisan elections": "x",
    "Category:Non-Partisan Solidarity Union Members of the Legislative Yuan": "x",
    "Category:Non-Partisan Solidarity Union politicians": "x",
    "Category:Non-Partisan Solidarity Union": "x",
    "Category:Non-passenger multiple units": "x",
    "Category:Non-periodic comets": "x",
    "Category:Non-petroleum based lubricants": "x",
    "Category:Non-plant crops": "x",
    "Category:Non-practicing entities": "x",
    "Category:Non-profit academic publishers": "x",
    "Category:Non-profit architecture organizations based in the United States": "x",
    "Category:Non-profit corporations": "x",
    "Category:Non-profit executives": "x",
    "Category:Non-profit institutes based in the United States": "x",
    "Category:Non-profit microfinance organizations based in North America": "x",
    "Category:Non-profit microfinance organizations": "x",
    "Category:Non-profit organisations based in Victoria (state)": "x",
    "Category:Non-profit organizations based in the New Orleans metropolitan area": "x",
    "Category:Non-profit organizations listed in Russia as foreign agents": "x",
    "Category:Non-profit youth organizations based in the United States": "x",
    "Category:Non-proliferation treaties": "x",
    "Category:Non-proportional multi-winner electoral systems": "x",
    "Category:Non-protein ion channel toxins": "x",
    "Category:Non-proteinogenic amino acids": "x",
    "Category:Non-public museums in the United States": "x",
    "Category:Non-public museums": "x",
    "Category:Non-pulmonic consonants": "x",
    "Category:Non-railway predecessors of railway companies": "x",
    "Category:Non-receptor tyrosine kinase inhibitors": "x",
    "Category:Non-registered political parties in Romania": "x",
    "Category:Non-religious Israeli communities": "x",
    "Category:Non-religious Israeli settlements": "x",
    "Category:Non-renewable resources": "x",
    "Category:Non-rocket spacelaunch": "x",
    "Category:Non-Romanian-language newspapers published in Romania": "x",
    "Category:Non-School institutions of the University of Cambridge": "x",
    "Category:Non-sexuality": "x",
    "Category:Non-SI metric units": "x",
    "Category:Non-sovereign monarchy": "x",
    "Category:Non-Spanish classical guitars": "x",
    "Category:Non-standard discography infoboxes": "x",
    "Category:Non-standard positional numeral systems": "x",
    "Category:Non-Status Indians": "x",
    "Category:Non-stoichiometric compounds": "x",
    "Category:Non-store retailing": "x",
    "Category:Non-subject-matter-related article-talk header templates": "x",
    "Category:Non-Summit": "x",
    "Category:Non-tariff barriers to trade": "x",
    "Category:Non-terminally differentiated (blast) cells": "x",
    "Category:Non-theatrical film production companies": "x",
    "Category:Non-Thoroughbred racehorses": "x",
    "Category:Non-timber forest products": "x",
    "Category:Non-tobacco nicotine products": "x",
    "Category:Non-tonal languages in tonal families": "x",
    "Category:Non-tricolorable knots and links": "x",
    "Category:Non-tropical storm articles by importance": "x",
    "Category:Non-tropical storm articles by quality": "x",
    "Category:Non-tropical storms articles needing expert attention": "x",
    "Category:Non-tropical storms templates": "x",
    "Category:Non-U.S. alumni of the Command and General Staff College": "x",
    "Category:Non-uniform random numbers": "x",
    "Category:North America territory (non-sovereign) templates": "x",
    "Category:Observances on non-Gregorian calendars": "x",
    "Category:Oceania territory (non-sovereign) templates": "x",
    "Category:OlyCatMenWomen on non-category page": "x",
    "Category:OlyCatMenWomen on non-Olympic page": "x",
    "Category:One Piece non-free media": "x",
    "Category:Open non-builders": "x",
    "Category:People from Thonon-les-Bains": "x",
    "Category:People from Tournon-sur-Rhône": "x",
    "Category:People with non-domiciled status in the United Kingdom": "x",
    "Category:Personnel of the Non-Combatant Corps": "x",
    "Category:Probability distributions with non-finite variance": "x",
    "Category:Regulation of non-governmental organizations": "x",
    "Category:Restricted titles (non-leading number sign)": "x",
    "Category:Secretaries-general of the Non-Aligned Movement": "x",
    "Category:Senescence in non-human organisms": "x",
    "Category:Ships sunk by non-combat internal explosions": "x",
    "Category:Singaporean Non-constituency Members of Parliament": "x",
    "Category:Snooker non-ranking competitions": "x",
    "Category:Soccerbase template using non-numeric ID": "x",
    "Category:Song articles with infoboxes with non-standard extra track listings": "x",
    "Category:Songs written by Marla Cannon-Goodman": "x",
    "Category:South America territory (non-sovereign) templates": "x",
    "Category:sports-people from Thonon-les-Bains": "x",
    "Category:Sri Lankan non-commissioned personnel": "x",
    "Category:SS non-commissioned officers": "x",
    "Category:Swedish non-commissioned personnel": "x",
    "Category:Tamil scholars of non-Tamil background": "x",
    "Category:Television non-maintenance tracking categories": "x",
    "Category:Theories of non-biological ageing": "x",
    "Category:Timelines of historically non-Chinese states in China": "x",
    "Category:Tonal languages in non-tonal families": "x",
    "Category:Top-importance English non-league football articles": "x",
    "Category:Top-importance Non-tropical storm articles": "x",
    "Category:Tribute albums to non-musicians": "x",
    "Category:Turkish non-commissioned personnel": "x",
    "Category:Unassessed English non-league football articles": "x",
    "Category:Unassessed Non-tropical storm articles": "x",
    "Category:Union army non-commissioned officers": "x",
    "Category:United States Air Force non-commissioned officers": "x",
    "Category:United States Army Air Forces non-commissioned officers": "x",
    "Category:United States Army non-commissioned officers": "x",
    "Category:United States Coast Guard non-commissioned officers": "x",
    "Category:United States Marine Corps non-commissioned officers": "x",
    "Category:United States Navy non-commissioned officers": "x",
    "Category:Unknown-importance English non-league football articles": "x",
    "Category:Unknown-importance Non-tropical storm articles": "x",
    "Category:Usage of portal image for non-existent portal": "x",
    "Category:Video games featuring non-playable protagonists": "x",
    "Category:Violent non-state actor incidents by country": "x",
    "Category:Violent non-state actor incidents in Africa": "x",
    "Category:Violent non-state actor incidents in Asia": "x",
    "Category:Violent non-state actor incidents in Europe": "x",
    "Category:Violent non-state actor incidents in Italy": "x",
    "Category:Violent non-state actor incidents in Mexico": "x",
    "Category:Violent non-state actor incidents in Nigeria": "x",
    "Category:Violent non-state actor incidents in North America": "x",
    "Category:Violent non-state actor incidents in South America": "x",
    "Category:Violent non-state actor incidents in the United Kingdom": "x",
    "Category:Violent non-state actor incidents in the United States": "x",
    "Category:Violent non-state actor incidents": "x",
    "Category:Violent non-state actors": "x",
    "Category:Winter Olympics by year category navigation — non-matching parameters": "x",
    "Category:Women heads of government of non-sovereign entities": "x",
}

non_fiction_empty = {
    "Category:New Zealand non-fiction literary awards": "x",
    "Category:New Zealand women non-fiction writers": "x",
    "Category:Abortion in non-fiction": "x",
    "Category:American non-fiction children's writers": "x",
    "Category:American non-fiction literary awards": "x",
    "Category:American non-fiction outdoors writers": "x",
    "Category:Arabic non-fiction books": "x",
    "Category:Arabic non-fiction literature": "x",
    "Category:Aromanian non-fiction writers": "x",
    "Category:Australian non-fiction book awards": "x",
    "Category:Bisexual non-fiction books": "x",
    "Category:Bosnian War in non-fiction": "x",
    "Category:British non-fiction literary awards": "x",
    "Category:British non-fiction outdoors writers": "x",
    "Category:Canadian non-fiction literary awards": "x",
    "Category:Children's non-fiction books": "x",
    "Category:Children's non-fiction writers": "x",
    "Category:Collaborative non-fiction books": "x",
    "Category:Collaborative non-fiction": "x",
    "Category:Dutch-language non-fiction books": "x",
    "Category:English non-fiction outdoors writers": "x",
    "Category:English-language non-fiction books": "x",
    "Category:Environmental non-fiction books": "x",
    "Category:French non-fiction outdoors writers": "x",
    "Category:French-language Canadian non-fiction writers": "x",
    "Category:French-language non-fiction books": "x",
    "Category:Gay non-fiction books": "x",
    "Category:German non-fiction literary awards": "x",
    "Category:German-language non-fiction books": "x",
    "Category:Governor General's Award–winning non-fiction books": "x",
    "Category:Governor General's Award–winning non-fiction writers": "x",
    "Category:Hugo Award for Best Non-Fiction Book–winning works": "x",
    "Category:Intersex non-fiction": "x",
    "Category:LDS non-fiction": "x",
    "Category:Lesbian non-fiction books": "x",
    "Category:LGBTQ non-fiction books": "x",
    "Category:Non-fiction book stub templates": "x",
    "Category:Non-fiction books about American prostitution": "x",
    "Category:Non-fiction books about American slavery": "x",
    "Category:Non-fiction books about artificial intelligence": "x",
    "Category:Non-fiction books about autism": "x",
    "Category:Non-fiction books about British prostitution": "x",
    "Category:Non-fiction books about Canadian prostitution": "x",
    "Category:Non-fiction books about cannibalism": "x",
    "Category:Non-fiction books about Colombian drug cartels": "x",
    "Category:Non-fiction books about consumerism": "x",
    "Category:Non-fiction books about contract killers": "x",
    "Category:Non-fiction books about elephants": "x",
    "Category:Non-fiction books about gangsters": "x",
    "Category:Non-fiction books about geisha": "x",
    "Category:Non-fiction books about guerrilla warfare": "x",
    "Category:Non-fiction books about horror": "x",
    "Category:Non-fiction books about Italian-American organized crime": "x",
    "Category:Non-fiction books about jihadism": "x",
    "Category:Non-fiction books about MDMA": "x",
    "Category:Non-fiction books about Mexican drug cartels": "x",
    "Category:Non-fiction books about mobsters": "x",
    "Category:Non-fiction books about musical theatre": "x",
    "Category:Non-fiction books about Native Americans": "x",
    "Category:Non-fiction books about outlaws of the American Old West": "x",
    "Category:Non-fiction books about piracy": "x",
    "Category:Non-fiction books about prostitution": "x",
    "Category:Non-fiction books about public relations": "x",
    "Category:Non-fiction books about same-sex sexuality": "x",
    "Category:Non-fiction books about Soviet repression": "x",
    "Category:Non-fiction books about submarine warfare": "x",
    "Category:Non-fiction books about the 1550 Bangladesh genocide": "x",
    "Category:Non-fiction books about the Armenian genocide": "x",
    "Category:Non-fiction books about the Central Intelligence Agency": "x",
    "Category:Non-fiction books about the French Connection": "x",
    "Category:Non-fiction books about the Great Depression": "x",
    "Category:Non-fiction books about the Great Game": "x",
    "Category:Non-fiction books about the Great Recession": "x",
    "Category:Non-fiction books about the Holodomor": "x",
    "Category:Non-fiction books about the illegal drug trade": "x",
    "Category:Non-fiction books about The Simpsons": "x",
    "Category:Non-fiction books about the subprime mortgage crisis": "x",
    "Category:Non-fiction books about the United States Marine Corps": "x",
    "Category:Non-fiction books about United States intelligence agencies": "x",
    "Category:Non-fiction books by discipline": "x",
    "Category:Non-fiction books by Norman Mailer": "x",
    "Category:Non-fiction books by William Boyd (writer)": "x",
    "Category:Non-fiction by Walter Scott": "x",
    "Category:Non-fiction Cyberpunk media": "x",
    "Category:Non-fiction genres": "x",
    "Category:Non-fiction literary awards": "x",
    "Category:Non-fiction literature about abortion": "x",
    "Category:Non-fiction literature by country": "x",
    "Category:Non-fiction literature from Georgia (country)": "x",
    "Category:Non-fiction literature from Northern Ireland": "x",
    "Category:Non-fiction literature": "x",
    "Category:Non-fiction novels of investigative journalism": "x",
    "Category:Non-fiction outdoors writers": "x",
    "Category:Non-fiction works about the Bosnian genocide": "x",
    "Category:Non-fiction works about the United States Marine Corps": "x",
    "Category:Non-fiction works about the United States military": "x",
    "Category:Non-fiction works by creator": "x",
    "Category:Non-fiction works by Elizabeth Gaskell": "x",
    "Category:Non-fiction writers about the French Connection": "x",
    "Category:Non-fiction": "x",
    "Category:Obsessive–compulsive disorder in non-fiction literature": "x",
    "Category:Siege of Sarajevo in non-fiction": "x",
    "Category:Spanish-language non-fiction books": "x",
    "Category:Sámi non-fiction writers": "x",
    "Category:Transgender non-fiction books": "x",
    "Category:Urdu-language non-fiction literature": "x",
    "Category:Writers by non-fiction genre": "x",
    "Category:Writers by non-fiction subject area": "",
}

to_test = [
    ("test_data_empty_result", data_empty_result),
    ("test_non_fiction_empty", non_fiction_empty),
]


@pytest.mark.parametrize("category, expected", test_1.items(), ids=test_1.keys())
@pytest.mark.fast
def test_data_empty_result(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", non_fiction_empty.items(), ids=non_fiction_empty.keys())
@pytest.mark.skip2
def test_non_fiction_empty(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.skip2
def test_non_dump(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.sport_lab_nat import sport_lab_nat_load_new

new_for_nat_female_xo_team_2_data = {
    "yemeni": "",
    "trinidad and tobago amateur basketball cup": "كأس ترنيدادية كرة سلة للهواة",
    "trinidad and tobago youth basketball cup": "كأس ترنيدادية كرة سلة للشباب",
    "trinidad and tobago mens basketball cup": "كأس ترنيدادية كرة سلة للرجال",
    "trinidad and tobago womens basketball cup": "كأس ترنيدادية كرة سلة للسيدات",
    "trinidad and tobago defunct basketball cup": "كؤوس كرة سلة ترنيدادية سابقة",
    "trinidad and tobago basketball cup": "كؤوس كرة سلة ترنيدادية",
    "trinidad and tobago domestic basketball cup": "كؤوس كرة سلة ترنيدادية محلية",
    # "yemeni football": "كرة قدم يمنية",
    # "new zealand basketball": "كرة سلة نيوزيلندية",  # Category:American_basketball
    "yemeni national football": "كرة قدم وطنية يمنية",
    "new zealand national basketball": "كرة سلة وطنية نيوزيلندية",
    "new zealand basketball teams": "فرق كرة سلة نيوزيلندية",
    "new zealand basketball national teams": "منتخبات كرة سلة نيوزيلندية",
    "new zealand domestic basketball": "كرة سلة نيوزيلندية محلية",
    "new zealand basketball championships": "بطولات كرة سلة نيوزيلندية",
    "new zealand national basketball championships": "بطولات كرة سلة وطنية نيوزيلندية",
    "new zealand national basketball champions": "أبطال كرة سلة وطنية نيوزيلندية",
    "trinidad and tobago basketball super leagues": "دوريات سوبر كرة سلة ترنيدادية",
    "trinidad and tobago womens basketball": "كرة سلة ترنيدادية نسائية",
    "trinidad and tobago current basketball seasons": "مواسم كرة سلة ترنيدادية حالية",
    # ---
    "trinidad and tobago professional basketball": "كرة سلة ترنيدادية للمحترفين",
    "trinidad and tobago domestic womens basketball": "كرة سلة ترنيدادية محلية للسيدات",
    "trinidad and tobago indoor basketball": "كرة سلة ترنيدادية داخل الصالات",
    "trinidad and tobago outdoor basketball": "كرة سلة ترنيدادية في الهواء الطلق",
    "trinidad and tobago defunct indoor basketball": "كرة سلة ترنيدادية داخل الصالات سابقة",
    "trinidad and tobago defunct outdoor basketball": "كرة سلة ترنيدادية في الهواء الطلق سابقة",
    "trinidad and tobago reserve basketball": "كرة سلة ترنيدادية احتياطية",
    "trinidad and tobago defunct basketball": "كرة سلة ترنيدادية سابقة",
    # tab[Category:Canadian domestic Soccer: "تصنيف:كرة قدم كندية محلية"
    # [european national womens volleyball teams] = "منتخبات كرة طائرة وطنية أوروبية للسيدات"
    "trinidad and tobago national womens basketball teams": "منتخبات كرة سلة وطنية ترنيدادية للسيدات",
    "trinidad and tobago national basketball teams": "منتخبات كرة سلة وطنية ترنيدادية",
    "trinidad and tobago national a basketball teams": "منتخبات كرة سلة محليين ترنيدادية",
    "trinidad and tobago national b basketball teams": "منتخبات كرة سلة رديفة ترنيدادية",
    "trinidad and tobago national reserve basketball teams": "منتخبات كرة سلة وطنية احتياطية ترنيدادية",
}

end_key_mappings_data = {
    # "yemeni football finals": "نهائيات كرة قدم يمنية",
    # "yemeni football": "كرة قدم يمنية",
    "yemeni national football": "كرة قدم وطنية يمنية",
    "yemeni national football home stadiums": "ملاعب كرة قدم وطنية يمنية",
    "yemeni national football teams fifth tier": "منتخبات كرة قدم وطنية يمنية من الدرجة الخامسة",
    "yemeni national football teams first tier": "منتخبات كرة قدم وطنية يمنية من الدرجة الأولى",
    "yemeni national football teams fourth tier": "منتخبات كرة قدم وطنية يمنية من الدرجة الرابعة",
    "yemeni national football teams premier": "منتخبات كرة قدم وطنية يمنية من الدرجة الممتازة",
    "yemeni national football teams second tier": "منتخبات كرة قدم وطنية يمنية من الدرجة الثانية",
    "yemeni national football teams seventh tier": "منتخبات كرة قدم وطنية يمنية من الدرجة السابعة",
    "yemeni national football teams sixth tier": "منتخبات كرة قدم وطنية يمنية من الدرجة السادسة",
    "yemeni national football teams third tier": "منتخبات كرة قدم وطنية يمنية من الدرجة الثالثة",
    "yemeni national football teams top tier": "منتخبات كرة قدم وطنية يمنية من الدرجة الأولى",
    "yemeni football teams fifth tier": "فرق كرة قدم يمنية من الدرجة الخامسة",
    "yemeni football teams first tier": "فرق كرة قدم يمنية من الدرجة الأولى",
    "yemeni football teams fourth tier": "فرق كرة قدم يمنية من الدرجة الرابعة",
    "yemeni football teams premier": "فرق كرة قدم يمنية من الدرجة الممتازة",
    "yemeni football teams second tier": "فرق كرة قدم يمنية من الدرجة الثانية",
    "yemeni football teams seventh tier": "فرق كرة قدم يمنية من الدرجة السابعة",
    "yemeni football teams sixth tier": "فرق كرة قدم يمنية من الدرجة السادسة",
    "yemeni football teams third tier": "فرق كرة قدم يمنية من الدرجة الثالثة",
    "yemeni football teams top tier": "فرق كرة قدم يمنية من الدرجة الأولى",
}

additional_keys_data = {
    "yemeni national amateur under-13 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 13 سنة للهواة",
    "yemeni national amateur under-14 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 14 سنة للهواة",
    "yemeni national amateur under-15 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 15 سنة للهواة",
    "yemeni national amateur under-16 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 16 سنة للهواة",
    "yemeni national amateur under-17 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 17 سنة للهواة",
    "yemeni national amateur under-18 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 18 سنة للهواة",
    "yemeni national amateur under-19 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 19 سنة للهواة",
    "yemeni national amateur under-20 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 20 سنة للهواة",
    "yemeni national amateur under-21 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 21 سنة للهواة",
    "yemeni national amateur under-23 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 23 سنة للهواة",
    "yemeni national amateur under-24 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 24 سنة للهواة",
    "yemeni national amateur basketball teams": "منتخبات كرة سلة وطنية يمنية للهواة",
    "yemeni national junior mens under-13 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 13 سنة للناشئين",
    "yemeni national junior mens under-14 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 14 سنة للناشئين",
    "yemeni national junior mens under-15 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 15 سنة للناشئين",
    "yemeni national junior mens under-16 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 16 سنة للناشئين",
    "yemeni national junior mens under-17 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 17 سنة للناشئين",
    "yemeni national junior mens under-18 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 18 سنة للناشئين",
    "yemeni national junior mens under-19 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 19 سنة للناشئين",
    "yemeni national junior mens under-20 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 20 سنة للناشئين",
    "yemeni national junior mens under-21 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 21 سنة للناشئين",
    "yemeni national junior mens under-23 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 23 سنة للناشئين",
    "yemeni national junior mens under-24 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 24 سنة للناشئين",
    "yemeni national junior mens basketball teams": "منتخبات كرة سلة وطنية يمنية للناشئين",
    "yemeni national junior womens under-13 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 13 سنة للناشئات",
    "yemeni national junior womens under-14 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 14 سنة للناشئات",
    "yemeni national junior womens under-15 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 15 سنة للناشئات",
    "yemeni national junior womens under-16 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 16 سنة للناشئات",
    "yemeni national junior womens under-17 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 17 سنة للناشئات",
    "yemeni national junior womens under-18 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 18 سنة للناشئات",
    "yemeni national junior womens under-19 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 19 سنة للناشئات",
    "yemeni national junior womens under-20 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 20 سنة للناشئات",
    "yemeni national junior womens under-21 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 21 سنة للناشئات",
    "yemeni national junior womens under-23 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 23 سنة للناشئات",
    "yemeni national junior womens under-24 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 24 سنة للناشئات",
    "yemeni national junior womens basketball teams": "منتخبات كرة سلة وطنية يمنية للناشئات",
    "yemeni national mens under-13 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 13 سنة للرجال",
    "yemeni national mens under-14 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 14 سنة للرجال",
    "yemeni national mens under-15 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 15 سنة للرجال",
    "yemeni national mens under-16 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 16 سنة للرجال",
    "yemeni national mens under-17 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 17 سنة للرجال",
    "yemeni national mens under-18 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 18 سنة للرجال",
    "yemeni national mens under-19 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 19 سنة للرجال",
    "yemeni national mens under-20 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 20 سنة للرجال",
    "yemeni national mens under-21 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 21 سنة للرجال",
    "yemeni national mens under-23 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 23 سنة للرجال",
    "yemeni national mens under-24 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 24 سنة للرجال",
    "yemeni national mens basketball teams": "منتخبات كرة سلة وطنية يمنية للرجال",
    "yemeni national under-13 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 13 سنة",
    "yemeni national under-14 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 14 سنة",
    "yemeni national under-15 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 15 سنة",
    "yemeni national under-16 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 16 سنة",
    "yemeni national under-17 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 17 سنة",
    "yemeni national under-18 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 18 سنة",
    "yemeni national under-19 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 19 سنة",
    "yemeni national under-20 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 20 سنة",
    "yemeni national under-21 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 21 سنة",
    "yemeni national under-23 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 23 سنة",
    "yemeni national under-24 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 24 سنة",
    "yemeni national womens under-13 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 13 سنة للسيدات",
    "yemeni national womens under-14 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 14 سنة للسيدات",
    "yemeni national womens under-15 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 15 سنة للسيدات",
    "yemeni national womens under-16 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 16 سنة للسيدات",
    "yemeni national womens under-17 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 17 سنة للسيدات",
    "yemeni national womens under-18 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 18 سنة للسيدات",
    "yemeni national womens under-19 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 19 سنة للسيدات",
    "yemeni national womens under-20 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 20 سنة للسيدات",
    "yemeni national womens under-21 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 21 سنة للسيدات",
    "yemeni national womens under-23 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 23 سنة للسيدات",
    "yemeni national womens under-24 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 24 سنة للسيدات",
    "yemeni national womens basketball teams": "منتخبات كرة سلة وطنية يمنية للسيدات",
    "yemeni national youth under-13 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 13 سنة للشباب",
    "yemeni national youth under-14 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 14 سنة للشباب",
    "yemeni national youth under-15 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 15 سنة للشباب",
    "yemeni national youth under-16 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 16 سنة للشباب",
    "yemeni national youth under-17 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 17 سنة للشباب",
    "yemeni national youth under-18 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 18 سنة للشباب",
    "yemeni national youth under-19 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 19 سنة للشباب",
    "yemeni national youth under-20 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 20 سنة للشباب",
    "yemeni national youth under-21 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 21 سنة للشباب",
    "yemeni national youth under-23 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 23 سنة للشباب",
    "yemeni national youth under-24 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 24 سنة للشباب",
    "yemeni national youth womens under-13 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 13 سنة للشابات",
    "yemeni national youth womens under-14 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 14 سنة للشابات",
    "yemeni national youth womens under-15 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 15 سنة للشابات",
    "yemeni national youth womens under-16 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 16 سنة للشابات",
    "yemeni national youth womens under-17 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 17 سنة للشابات",
    "yemeni national youth womens under-18 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 18 سنة للشابات",
    "yemeni national youth womens under-19 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 19 سنة للشابات",
    "yemeni national youth womens under-20 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 20 سنة للشابات",
    "yemeni national youth womens under-21 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 21 سنة للشابات",
    "yemeni national youth womens under-23 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 23 سنة للشابات",
    "yemeni national youth womens under-24 basketball teams": "منتخبات كرة سلة وطنية يمنية تحت 24 سنة للشابات",
    "yemeni national youth womens basketball teams": "منتخبات كرة سلة وطنية يمنية للشابات",
    "yemeni national youth basketball teams": "منتخبات كرة سلة وطنية يمنية للشباب",
    "yemeni under-13 basketball": "كرة سلة يمنية تحت 13 سنة",
    "yemeni under-14 basketball": "كرة سلة يمنية تحت 14 سنة",
    "yemeni under-15 basketball": "كرة سلة يمنية تحت 15 سنة",
    "yemeni under-16 basketball": "كرة سلة يمنية تحت 16 سنة",
    "yemeni under-17 basketball": "كرة سلة يمنية تحت 17 سنة",
    "yemeni under-18 basketball": "كرة سلة يمنية تحت 18 سنة",
    "yemeni under-19 basketball": "كرة سلة يمنية تحت 19 سنة",
    "yemeni under-20 basketball": "كرة سلة يمنية تحت 20 سنة",
    "yemeni under-21 basketball": "كرة سلة يمنية تحت 21 سنة",
    "yemeni under-23 basketball": "كرة سلة يمنية تحت 23 سنة",
    "yemeni under-24 basketball": "كرة سلة يمنية تحت 24 سنة",
}


@pytest.mark.parametrize(
    "key,expected", new_for_nat_female_xo_team_2_data.items(), ids=new_for_nat_female_xo_team_2_data.keys()
)
@pytest.mark.unit
def test_new_for_nat_female_xo_team_2_data(key: str, expected: str) -> None:
    result2 = sport_lab_nat_load_new(key)
    assert result2 == expected


@pytest.mark.parametrize("key,expected", end_key_mappings_data.items(), ids=end_key_mappings_data.keys())
@pytest.mark.unit
def test_end_key_mappings_data(key: str, expected: str) -> None:
    result2 = sport_lab_nat_load_new(key)
    assert result2 == expected


@pytest.mark.parametrize("key,expected", additional_keys_data.items(), ids=additional_keys_data.keys())
@pytest.mark.unit
def test_additional_keys_data(key: str, expected: str) -> None:
    result2 = sport_lab_nat_load_new(key)
    assert result2 == expected


to_test = [
    ("test_new_for_nat_female_xo_team_2_data", new_for_nat_female_xo_team_2_data),
    ("test_end_key_mappings_data", end_key_mappings_data),
    ("test_additional_keys_data", additional_keys_data),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, sport_lab_nat_load_new)
    dump_diff(diff_result, name)

    # add_result = {x: v for x, v in data.items() if x in diff_result and "" == diff_result.get(x)}
    # dump_diff(add_result, f"{name}_empty")

    # add_result2 = {x: v for x, v in data.items() if x not in add_result}
    # dump_diff(add_result2, f"{name}_not_empty")

    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""Translation helpers for United States counties, states, and parties."""

from __future__ import annotations

from collections.abc import Mapping

from ...helps import len_print
from ..utils.json_dir import open_json_file

_USA_PARTY_LABELS = {
    "democratic republican": "الحزب الديمقراطي الجمهوري",
    "democratic-republican": "الحزب الديمقراطي الجمهوري",
    "democratic-republican party": "الحزب الديمقراطي الجمهوري",
    "anti-Administration party": "حزب معاداة الإدارة",
    "anti Administration party": "حزب معاداة الإدارة",
    "Pro Administration Party": "حزب دعم الإدارة",
    "Pro-Administration Party": "حزب دعم الإدارة",
    "Anti-Monopoly Party": "حزب مكافحة الاحتكار",
    "Free Soil Party": "حزب التربة الحرة",
    "Liberty Party (1840)": "حزب الحرية 1840",
    "Opposition Party": "أوبوسيشن بارتي",
    "Readjuster Party": "ريدجوستر بارتي",
    "Silver Republican Party": "الحزب الجمهوري الفضي",
    "conditional Union Party": "حزب الاتحاد المشروط",
    "Unconditional Union Party": "حزب الاتحاد غير المشروط",
    "Asian-American": "",
    "Censured or reprimanded": "",
    # 'Expelled' : 'مطرودون' ,
    "Independent": "",
    "Jewish": "",
    "Nonpartisan League": "",
    "democratic party": "الحزب الديمقراطي",
    "republican party": "الحزب الجمهوري",
    "whig party": "حزب اليمين",
    "National Republican Party": "الحزب الجمهوري الوطني",
    "National Republican": "الحزب الجمهوري الوطني",
    "Unionist Party": "الحزب الوحدوي",
    "Unionist": "الحزب الوحدوي",
    "Know-Nothing": "حزب لا أدري",
    "Know Nothing": "حزب لا أدري",
    "alaskan independence Party": "حزب استقلال ألاسكا",
    "anti-masonic Party": "حزب مناهضة الماسونية",
    "anti masonic Party": "حزب مناهضة الماسونية",
    "constitutional union Party": "حزب الاتحاد الدستوري",
    # 'Country Party (Rhode Island)' : 'حزب الدولة (رود آيلاند)',
    "Greenback Party": "حزب الدولار الأمريكي",
    "Farmer–Labor Party": "حزب العمال المزارعين",
    "Farmer Labor Party": "حزب العمال المزارعين",
    "Federalist Party": "الحزب الفيدرالي الأمريكي",
    # 'Independent' : 'مستقلون',
    "Independent Voters Association": "رابطة الناخبين المستقلين",
    "Law and Order Party of Rhode Island": "حزب القانون والنظام في رود آيلاند",
    "Liberal Republican Party": "الحزب الجمهوري الليبرالي",
    "Nonpartisan League state": "الرابطة غير الحزبية",
    "Nullifier Party": "حزب الرفض",
    "People's Party": "حزب الشعب",
    "Peoples Party": "حزب الشعب",
    "Silver Party": "الحزب الفضي",
    "Green Party": "حزب الخضر",
    "Green": "حزب الخضر",
    "Citizens Party": "حزب المواطنين",
    "Solidarity": "حزب التضامن",
    "Socialist Party USA": "الحزب الاشتراكي",
    "Socialist Party": "الحزب الاشتراكي",
    "Liberty Union Party": "حزب الحرية المتحد",
}

USA_PARTY_LABELS = {x.strip(): y.strip() for x, y in _USA_PARTY_LABELS.items() if y.strip()}


def _build_party_derived_keys(party_labels: Mapping[str, str]) -> dict[str, str]:
    derived_keys: dict[str, str] = {}

    for party_name, party_label in party_labels.items():
        normalized_party_name = party_name.lower()

        if not party_label.strip():
            continue

        derived_keys[normalized_party_name] = party_label
        derived_keys[f"{normalized_party_name} (united states)"] = party_label
        derived_keys[f"{normalized_party_name}s (united states)"] = party_label

        # derived_keys[ '%s members of the united states congress' % normalized_party_name ] = 'أعضاء الكونغرس الأمريكي من %s' % party_label
        derived_keys[f"{normalized_party_name} united states senators"] = f"أعضاء مجلس الشيوخ الأمريكي من {party_label}"
        derived_keys[f"{normalized_party_name} members"] = f"أعضاء {party_label}"
        derived_keys[
            f"{normalized_party_name} members of the united states house of representatives"
        ] = f"أعضاء مجلس النواب الأمريكي من {party_label}"
        derived_keys[
            f"{normalized_party_name} members of the united states house-of-representatives"
        ] = f"أعضاء مجلس النواب الأمريكي من {party_label}"

        derived_keys[f"{normalized_party_name} presidential nominees"] = f"مرشحون لمنصب الرئيس من {party_label}"
        derived_keys[
            f"{normalized_party_name} vice presidential nominees"
        ] = f"مرشحون لمنصب نائب الرئيس من {party_label}"

        derived_keys[
            f"{normalized_party_name} (united states) vice presidential nominees"
        ] = f"مرشحون لمنصب نائب الرئيس من {party_label}"
        derived_keys[
            f"{normalized_party_name} (united states) presidential nominees"
        ] = f"مرشحون لمنصب الرئيس من {party_label}"

        derived_keys[f"{normalized_party_name} (united states) politicians"] = f"سياسيو {party_label}"
        derived_keys[f"{normalized_party_name} politicians"] = f"سياسيو {party_label}"

        derived_keys[
            f"{normalized_party_name} vice presidents of the united states"
        ] = f"نواب رئيس الولايات المتحدة من {party_label}"
        derived_keys[
            f"{normalized_party_name} presidents of the united states"
        ] = f"رؤساء الولايات المتحدة من {party_label}"
        derived_keys[f"{normalized_party_name} state governors"] = f"حكام ولايات من {party_label}"
        derived_keys[
            f"{normalized_party_name} state governors of the united states"
        ] = f"حكام ولايات أمريكية من {party_label}"

    return derived_keys


# US_COUNTY_TRANSLATIONS = load_json_mapping("geography/us_counties.json")
US_COUNTY_TRANSLATIONS = open_json_file("geography/us_counties.json") or {}

USA_PARTY_DERIVED_KEYS = _build_party_derived_keys(USA_PARTY_LABELS)

__all__ = [
    "USA_PARTY_DERIVED_KEYS",
    "US_COUNTY_TRANSLATIONS",
    "USA_PARTY_LABELS",
]

len_print.data_len(
    "us_counties.py",
    {
        "USA_PARTY_LABELS": USA_PARTY_LABELS,
        "USA_PARTY_DERIVED_KEYS": USA_PARTY_DERIVED_KEYS,
        "US_COUNTY_TRANSLATIONS": US_COUNTY_TRANSLATIONS,
    },
)



from typing import Dict

import pytest

from ArWikiCats.translations.nats.Nationality import (
    All_Nat,
    NationalityEntry,
    build_american_forms,
    build_lookup_tables,
    load_sources,
    normalize_aliases,
)

# -------------------------------------------------------------------
# Helpers
# -------------------------------------------------------------------


def make_entry(
    male: str = "",
    males: str = "",
    women: str = "",
    females: str = "",
    en: str = "",
    ar: str = "",
) -> NationalityEntry:
    """Helper to build a NationalityEntry quickly."""
    return {
        "male": male,
        "males": males,
        "female": women,
        "females": females,
        "en": en,
        "ar": ar,
    }


# -------------------------------------------------------------------
# Tests for load_sources
# -------------------------------------------------------------------


def test_load_sources_returns_normalized_entries(monkeypatch: pytest.MonkeyPatch) -> None:
    """load_sources should return dict of NationalityEntry with all keys present and string values."""

    def fake_open_json_file(name: str) -> dict[str, dict[str, str]] | dict:
        if name == "nationalities/nationalities_data.json":
            return {
                "yemeni": {"en": "yemen", "ar": "اليمن", "male": "يمني"},
            }
        if name == "nationalities/sub_nats.json":
            return {
                "italian": {"male": "إيطالي", "en": "italy", "ar": "إيطاليا"},
            }
        return {}

    # Patch open_json_file used inside load_sources
    monkeypatch.setattr("ArWikiCats.translations.nats.Nationality.open_json_file", fake_open_json_file)

    data = load_sources()

    assert isinstance(data, dict)
    assert "yemeni" in data
    assert "italian" in data

    for entry in data.values():
        # Ensure all required keys are present
        assert set(entry.keys()) == {"male", "males", "female", "females", "en", "ar", "the_male", "the_female"}
        # Ensure all values are strings
        assert all(isinstance(v, str) for v in entry.values())


# -------------------------------------------------------------------
# Tests for normalize_aliases
# -------------------------------------------------------------------


def test_normalize_aliases_alias_copy() -> None:
    """Alias keys (e.g. russians) should reuse target entry (russian)."""

    all_nat_o: Dict[str, NationalityEntry] = {
        "russian": make_entry(male="روسي", en="russia", ar="روسيا"),
        "russians": make_entry(),  # will be overwritten
    }

    out = normalize_aliases(all_nat_o)
    assert out["russians"]["en"] == "russia"
    assert out["russians"]["ar"] == "روسيا"
    assert out["russians"]["male"] == "روسي"


def test_normalize_aliases_georgia_country_copy() -> None:
    """georgia (country) should be derived from georgian entry and override 'en'."""

    base = {"georgian": make_entry(male="جورجي", en="georgia", ar="جورجي")}

    out = normalize_aliases(base)
    assert "georgia (country)" in out
    g = out["georgia (country)"]
    assert g["en"] == "georgia (country)"
    assert g["ar"] == "جورجي"
    assert g["male"] == "جورجي"


# -------------------------------------------------------------------
# Tests for build_american_forms
# -------------------------------------------------------------------


def test_build_american_forms_basic() -> None:
    """build_american_forms should create '-american' keys when there is at least one gendered form."""

    all_nat_o = {
        "yemeni": make_entry(male="يمني", en="yemen", ar="اليمن"),
    }

    out = build_american_forms(all_nat_o)

    assert "yemeni-american" in out
    entry = out["yemeni-american"]
    assert entry["male"] == "أمريكي يمني"


def test_build_american_forms_skips_if_no_gender() -> None:
    """No american form should be generated when all gender fields are empty."""

    all_nat_o = {
        "abc": make_entry(en="abc", ar="ايه بي سي"),  # all gender fields empty
    }

    out = build_american_forms(all_nat_o)

    assert out == {}


def test_build_american_forms_jewish_special_case() -> None:
    """For 'jewish' key, both 'jewish-american' and 'jewish american' should be created."""

    all_nat_o = {
        "jewish": make_entry(male="يهودي", en="jews", ar="يهود"),
    }

    out = build_american_forms(all_nat_o)

    assert "jewish-american" in out
    assert "jewish american" in out
    assert out["jewish-american"]["male"].startswith("أمريكي")
    assert out["jewish american"]["male"].startswith("أمريكي")


# -------------------------------------------------------------------
# Tests for build_lookup_tables
# -------------------------------------------------------------------


def test_build_lookup_tables_nat_men_and_country() -> None:
    """build_lookup_tables should fill Nat_men and countries_from_nat correctly."""

    all_nat = {
        "yemeni": make_entry(male="يمني", en="yemen", ar="اليمن"),
    }

    result = build_lookup_tables(all_nat)
    Nat_men = result["Nat_men"]
    countries_from_nat = result["countries_from_nat"]
    all_country_ar = result["all_country_ar"]

    assert Nat_men["yemeni"] == "يمني"
    assert countries_from_nat["yemen"] == "اليمن"
    assert all_country_ar["yemen"] == "اليمن"


def test_build_lookup_tables_the_prefix_normalization() -> None:
    """'the X' should be normalized to 'X' in countries_from_nat."""

    all_nat = {
        "british": make_entry(male="بريطاني", en="the uk", ar="المملكة المتحدة"),
    }

    result = build_lookup_tables(all_nat)
    countries_from_nat = result["countries_from_nat"]

    assert countries_from_nat["uk"] == "المملكة المتحدة"


def test_build_lookup_tables_uppercase_en_normalization() -> None:
    """Uppercase English names should be lowercased in mapping keys."""

    all_nat = {
        "italian": make_entry(male="إيطالي", en="ITALY", ar="إيطاليا"),
    }

    result = build_lookup_tables(all_nat)
    countries_from_nat = result["countries_from_nat"]

    assert "italy" in countries_from_nat
    assert countries_from_nat["italy"] == "إيطاليا"


def test_build_lookup_tables_en_nats_to_ar_label() -> None:
    """en_nats_to_ar_label should map nationality keys to Arabic labels."""

    all_nat = {
        "yemeni": make_entry(male="يمني", en="yemen", ar="اليمن"),
    }

    result = build_lookup_tables(all_nat)
    en_nats_to_ar_label = result["en_nats_to_ar_label"]

    assert en_nats_to_ar_label["yemeni"] == "اليمن"


def test_build_lookup_tables_iranian_special_case() -> None:
    """Special case: 'iranian' should create 'islamic republic of iran' key in countries_nat_en_key."""

    all_nat = {
        "iranian": make_entry(male="إيراني", en="iran", ar="إيران"),
    }

    result = build_lookup_tables(all_nat)
    keys_en = result["countries_nat_en_key"]

    assert "islamic republic of iran" in keys_en
    assert keys_en["islamic republic of iran"]["ar"] == "إيران"


# -------------------------------------------------------------------
# Integration tests
# -------------------------------------------------------------------


def test_full_pipeline_minimal() -> None:
    """End-to-end integration: from raw data → All_Nat → american forms → lookup tables."""

    raw = {
        "yemeni": make_entry(
            male="يمني",
            males="يمنيون",
            women="يمنية",
            females="يمنيات",
            en="yemen",
            ar="اليمن",
        )
    }

    # Build All_Nat from raw (simulate what module does)
    all_nat = {k.lower(): v for k, v in raw.items()}

    # Add American forms
    all_nat = build_american_forms(raw)
    assert "yemeni-american" in all_nat

    # Build lookup tables
    result = build_lookup_tables(all_nat)

    assert result["Nat_mens"]["yemeni-american"] == "أمريكيون يمنيون"


def test_full_pipeline_with_alias_and_american() -> None:
    """Integration that includes alias normalization + american forms + lookups."""

    # Start from a minimal nationalities_data-like structure
    all_nat_o = {
        "russian": make_entry(
            male="روسي",
            males="روس",
            women="روسية",
            females="روسيات",
            en="russia",
            ar="روسيا",
        )
    }

    # Apply alias normalization (this will add russians and others)
    all_nat_o = normalize_aliases(all_nat_o)

    # Lower-case main All_Nat dict
    all_nat = {k.lower(): v for k, v in all_nat_o.items()}

    # Lookup tables
    result = build_lookup_tables(all_nat)

    assert "russian" in result["Nat_men"]
    assert result["countries_from_nat"]["russia"] == "روسيا"


def test_normalize_aliases_keys() -> None:
    """Test that alias normalization works correctly for keys."""

    assert "turkish cypriot" in All_Nat
    assert "northern cypriot" in All_Nat
    assert All_Nat["turkish cypriot"] == All_Nat["northern cypriot"]



#!/usr/bin/python3
"""

Helper utilities for resolving film- and media-related categories.

"""

import functools

from ...helps import logger
from ...translations import (
    Films_key_333,
    Films_key_CAO,
    television_keys,
)
from .resolve_films_labels import get_films_key_tyty_new


@functools.lru_cache(maxsize=None)
def get_Films_key_CAO(country_identifier: str) -> str:
    """
    Resolve an Arabic label for a composite television-style film key.

    Given a country or category identifier that may be composed of a prefix and a known television suffix, match the suffix, look up the prefix label, and combine them into a localized Arabic label.

    Parameters:
        country_identifier (str): The input identifier (e.g., a composite television/category key) to resolve.

    Returns:
        str: The resolved Arabic label when a matching suffix and prefix are found, or an empty string if no resolution is possible.
    """

    logger.debug(f"<<lightblue>> get_Films_key_CAO : {country_identifier=} ")
    normalized_identifier = country_identifier.lower().strip()

    resolved_label = ""

    for suffix, suffix_translation in television_keys.items():
        if not normalized_identifier.endswith(suffix.lower()):
            continue

        prefix = normalized_identifier[: -len(suffix)].strip()
        logger.debug(f'<<lightblue>> {prefix=}, endswith:"{suffix}" ')

        prefix_label = Films_key_333.get(prefix.strip(), "")

        if not prefix_label:
            continue

        logger.debug(f"<<lightblue>> get_Films_key_CAO : {prefix=} ")

        resolved_label = f"{suffix_translation} {prefix_label}"

        if resolved_label:
            logger.info(f"<<lightblue>> get_Films_key_CAO: new {resolved_label=} ")
            break

    logger.info_if_or_debug(
        f"<<yellow>> end get_Films_key_CAO:{country_identifier=}, {resolved_label=}", resolved_label
    )
    return resolved_label


@functools.lru_cache(maxsize=None)
# @dump_data(1)
def Films(category: str) -> str:
    """
    Resolve the Arabic label for a given film category.

    Returns:
        str: Arabic label corresponding to the category, or an empty string if no mapping is found.
    """

    normalized_category = category.lower().replace("_", " ").replace("-", " ")

    logger.debug(f"<<yellow>> start Films: {normalized_category=}")

    result = (
        Films_key_CAO.get(normalized_category, "")
        or get_Films_key_CAO(normalized_category)
        or get_films_key_tyty_new(normalized_category)
        or ""
    )

    logger.info_if_or_debug(f"<<yellow>> end Films: {normalized_category=}, {result=}", result)
    return result


__all__ = [
    "Films",
]



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {
    "Category:Afghan emigrants": "تصنيف:أفغان مهاجرون",
    "Category:Afghan expatriates": "تصنيف:أفغان مغتربون",
    "Category:Ambassadors of Afghanistan to Argentina": "تصنيف:سفراء أفغانستان لدى الأرجنتين",
    "Category:Ambassadors of Afghanistan to Australia": "تصنيف:سفراء أفغانستان لدى أستراليا",
    "Category:American people by status": "تصنيف:أمريكيون حسب الحالة",
    "Category:American people of the Iraq War": "تصنيف:أمريكيون في حرب العراق",
    "Category:European women in business": "تصنيف:أوروبيات في الأعمال",
    "Category:Ivorian emigrants": "تصنيف:إيفواريون مهاجرون",
    "Category:Ivorian expatriates": "تصنيف:إيفواريون مغتربون",
    "Category:Polish businesspeople": "تصنيف:شخصيات أعمال بولندية",
    "Category:Polish women in business": "تصنيف:بولنديات في الأعمال",
}

data2 = {
    # "Category:sports-people from Westchester County, New York": "تصنيف:رياضيون من مقاطعة ويستتشستر (نيويورك)",
    "Category:Mixed martial artists from Massachusetts": "تصنيف:مقاتلو فنون قتالية مختلطة من ماساتشوستس",
    "Category:People from Buenos Aires": "تصنيف:أشخاص من بوينس آيرس",
    "Category:Players of American football from Massachusetts": "تصنيف:لاعبو كرة قدم أمريكية من ماساتشوستس",
    "Category:Professional wrestlers from Massachusetts": "تصنيف:مصارعون محترفون من ماساتشوستس",
    "Category:Racing drivers from Massachusetts": "تصنيف:سائقو سيارات سباق من ماساتشوستس",
    "Category:Singers from Buenos Aires": "تصنيف:مغنون من بوينس آيرس",
    "Category:Soccer players from Massachusetts": "تصنيف:لاعبو كرة قدم من ماساتشوستس",
    "Category:Sports coaches from Massachusetts": "تصنيف:مدربو رياضة من ماساتشوستس",
    "Category:Sportswriters from Massachusetts": "تصنيف:كتاب رياضيون من ماساتشوستس",
}
data3 = {
    "Category:Baseball players from Massachusetts": "تصنيف:لاعبو كرة قاعدة من ماساتشوستس",
    "Category:Basketball coaches from Indiana": "تصنيف:مدربو كرة سلة من إنديانا",
    "Category:Basketball people from Indiana": "تصنيف:أعلام كرة سلة من إنديانا",
    "Category:Basketball players from Indiana": "تصنيف:لاعبو كرة سلة من إنديانا",
    "Category:Basketball players from Massachusetts": "تصنيف:لاعبو كرة سلة من ماساتشوستس",
    "Category:Boxers from Massachusetts": "تصنيف:ملاكمون من ماساتشوستس",
    "Category:Female single skaters from Georgia (country)": "تصنيف:متزلجات فرديات من جورجيا",
    "Category:Golfers from Massachusetts": "تصنيف:لاعبو غولف من ماساتشوستس",
    "Category:Ice hockey people from Massachusetts": "تصنيف:أعلام هوكي جليد من ماساتشوستس",
    "Category:Immigrants to the United Kingdom from Aden": "تصنيف:مهاجرون إلى المملكة المتحدة من عدن",
    "Category:Kickboxers from Massachusetts": "تصنيف:مقاتلو كيك بوكسنغ من ماساتشوستس",
    "Category:Lacrosse players from Massachusetts": "تصنيف:لاعبو لاكروس من ماساتشوستس",
    "Category:Swimmers from Massachusetts": "تصنيف:سباحون من ماساتشوستس",
    "Category:Tennis people from Massachusetts": "تصنيف:أعلام كرة مضرب من ماساتشوستس",
    "Category:Track and field athletes from Massachusetts": "تصنيف:رياضيو المسار والميدان من ماساتشوستس",
}

to_test = [
    ("test_people_labels_1", data1),
    ("test_people_labels_2", data2),
    ("test_people_labels_3", data3),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
@pytest.mark.fast
def test_people_labels_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data2.items(), ids=data2.keys())
@pytest.mark.fast
def test_people_labels_2(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data3.items(), ids=data3.keys())
@pytest.mark.fast
def test_people_labels_3(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_peoples_2(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""Comprehensive pytest suite for move_years module."""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.fix.mv_years import move_by_in, move_years_first

move_years_first_data = {
    "عقد 1910 في بابوا غينيا الجديدة": "بابوا غينيا الجديدة في عقد 1910",
    "2016 في بابوا غينيا الجديدة حسب الشهر": "بابوا غينيا الجديدة في 2016 حسب الشهر",
    "1330 في كرة قدم دولية للرجال": "كرة قدم دولية للرجال في 1330",
    "2023 في أقاليم ما وراء البحار البريطانية": "أقاليم ما وراء البحار البريطانية في 2023",
    "عقد 1880 في الأفلام حسب البلد": "الأفلام في عقد 1880 حسب البلد",
    "عقد 1880 في أفلام حسب البلد": "أفلام في عقد 1880 حسب البلد",
    "1994–95 في اتحاد الرجبي الأوروبي": "اتحاد الرجبي الأوروبي في 1994–95",
    "1994–95 في اتحاد الرجبي الأوروبي حسب البلد": "اتحاد الرجبي الأوروبي في 1994–95 حسب البلد",
    "عقد 2000 في السينما الأمريكية": "السينما الأمريكية في عقد 2000",
    "2006 في رياضة أيرلندية شمالية": "رياضة أيرلندية شمالية في 2006",
    "2006 في رياضة كورية شمالية": "رياضة كورية شمالية في 2006",
    "2017 في كرة القدم الإماراتية": "كرة القدم الإماراتية في 2017",
    "الألفية 10 في الخيال": "الخيال في الألفية 10",
    "عقد 1270 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1270",
    "عقد 2000 في الولايات المتحدة حسب الولاية": "الولايات المتحدة في عقد 2000 حسب الولاية",
    "القرن 21 في التشيك": "التشيك في القرن 21",
    "القرن 21 في قطر": "قطر في القرن 21",
    "1433 في بوتان": "بوتان في 1433",
    "1448 في البرتغال": "البرتغال في 1448",
    "القرن 10 في آسيا": "آسيا في القرن 10",
    "القرن 10 في آيسلندا": "آيسلندا في القرن 10",
    "القرن 10 في أرمينيا": "أرمينيا في القرن 10",
    "القرن 10 في ألمانيا": "ألمانيا في القرن 10",
    "القرن 10 في أمريكا الجنوبية": "أمريكا الجنوبية في القرن 10",
    "القرن 10 في أمريكا الشمالية": "أمريكا الشمالية في القرن 10",
    "القرن 10 في أوروبا": "أوروبا في القرن 10",
    "القرن 10 في أوقيانوسيا": "أوقيانوسيا في القرن 10",
    "القرن 10 في أوكرانيا": "أوكرانيا في القرن 10",
    "القرن 10 في أيرلندا": "أيرلندا في القرن 10",
    "القرن 10 في إسبانيا": "إسبانيا في القرن 10",
    "القرن 10 في إسكتلندا": "إسكتلندا في القرن 10",
    "القرن 10 في إفريقيا": "إفريقيا في القرن 10",
    "القرن 10 في إنجلترا": "إنجلترا في القرن 10",
    "القرن 10 في إندونيسيا": "إندونيسيا في القرن 10",
    "القرن 10 في إيران": "إيران في القرن 10",
    "القرن 10 في إيطاليا": "إيطاليا في القرن 10",
    "القرن 10 في الأندلس": "الأندلس في القرن 10",
    "القرن 10 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في القرن 10",
    "القرن 10 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في القرن 10",
    "القرن 10 في البرتغال": "البرتغال في القرن 10",
    "القرن 10 في التاريخ الاقتصادي": "التاريخ الاقتصادي في القرن 10",
    "القرن 10 في التبت": "التبت في القرن 10",
    "القرن 10 في الدنمارك": "الدنمارك في القرن 10",
    "القرن 10 في الدولة البابوية": "الدولة البابوية في القرن 10",
    "القرن 10 في الدولة العباسية": "الدولة العباسية في القرن 10",
    "القرن 10 في الدولة الفاطمية": "الدولة الفاطمية في القرن 10",
    "القرن 10 في السويد": "السويد في القرن 10",
    "القرن 10 في الشرق الأوسط": "الشرق الأوسط في القرن 10",
    "القرن 10 في الصين": "الصين في القرن 10",
    "القرن 10 في الطب": "الطب في القرن 10",
    "القرن 10 في العراق": "العراق في القرن 10",
    "القرن 10 في الفنون": "الفنون في القرن 10",
    "القرن 10 في المجر": "المجر في القرن 10",
    "القرن 10 في المغرب": "المغرب في القرن 10",
    "القرن 10 في النرويج": "النرويج في القرن 10",
    "القرن 10 في الهند": "الهند في القرن 10",
    "القرن 10 في اليابان": "اليابان في القرن 10",
    "القرن 10 في اليمن": "اليمن في القرن 10",
    "القرن 10 في اليونان": "اليونان في القرن 10",
    "القرن 10 في بريطانيا العظمى": "بريطانيا العظمى في القرن 10",
    "القرن 10 في بلجيكا": "بلجيكا في القرن 10",
    "القرن 10 في بلغاريا": "بلغاريا في القرن 10",
    "القرن 10 في بورما": "بورما في القرن 10",
    "القرن 10 في بولندا": "بولندا في القرن 10",
    "القرن 10 في بوهيميا": "بوهيميا في القرن 10",
    "القرن 10 في تايلاند": "تايلاند في القرن 10",
    "القرن 10 في تركيا": "تركيا في القرن 10",
    "القرن 10 في تونغا": "تونغا في القرن 10",
    "القرن 10 في جرينلاند": "جرينلاند في القرن 10",
    "القرن 10 في جمهورية البندقية": "جمهورية البندقية في القرن 10",
    "القرن 10 في جنوب شرق آسيا": "جنوب شرق آسيا في القرن 10",
    "القرن 10 في جورجيا": "جورجيا في القرن 10",
    "القرن 10 في روسيا": "روسيا في القرن 10",
    "القرن 10 في رومانيا": "رومانيا في القرن 10",
    "القرن 10 في سريلانكا": "سريلانكا في القرن 10",
    "القرن 10 في سكونا (السويد)": "سكونا (السويد) في القرن 10",
    "القرن 10 في سوريا": "سوريا في القرن 10",
    "القرن 10 في صربيا": "صربيا في القرن 10",
    "القرن 10 في فرنسا": "فرنسا في القرن 10",
    "القرن 10 في فيتنام": "فيتنام في القرن 10",
    "القرن 10 في كرواتيا": "كرواتيا في القرن 10",
    "القرن 10 في كمبوديا": "كمبوديا في القرن 10",
    "القرن 10 في كوريا": "كوريا في القرن 10",
    "القرن 10 في كييف روس": "كييف روس في القرن 10",
    "القرن 10 في مايا": "مايا في القرن 10",
    "القرن 10 في مصر": "مصر في القرن 10",
    "القرن 10 في مملكة الفرنجة الشرقيين": "مملكة الفرنجة الشرقيين في القرن 10",
    "القرن 10 في مملكة الفرنجة الغربيين": "مملكة الفرنجة الغربيين في القرن 10",
    "القرن 10 في مملكة ليون": "مملكة ليون في القرن 10",
    "القرن 10 في منغوليا": "منغوليا في القرن 10",
    "القرن 10 في نيبال": "نيبال في القرن 10",
    "القرن 10 في ويلز": "ويلز في القرن 10",
    "القرن 10 ق م في آشور": "آشور في القرن 10 ق م",
    "القرن 10 ق م في الصين": "الصين في القرن 10 ق م",
    "القرن 12 في اليمن": "اليمن في القرن 12",
    "القرن 12 في اليونان": "اليونان في القرن 12",
    "القرن 12 في بريطانيا العظمى": "بريطانيا العظمى في القرن 12",
    "القرن 12 في بلجيكا": "بلجيكا في القرن 12",
    "القرن 12 في بلغاريا": "بلغاريا في القرن 12",
    "القرن 12 في بورما": "بورما في القرن 12",
    "القرن 12 في بولندا": "بولندا في القرن 12",
    "القرن 12 في بوهيميا": "بوهيميا في القرن 12",
    "القرن 12 في تايلاند": "تايلاند في القرن 12",
    "القرن 12 في تركيا": "تركيا في القرن 12",
    "القرن 12 في جزيرة مان": "جزيرة مان في القرن 12",
    "القرن 12 في جمهورية البندقية": "جمهورية البندقية في القرن 12",
    "القرن 12 في جمهورية جنوة": "جمهورية جنوة في القرن 12",
    "القرن 12 في جنوب شرق آسيا": "جنوب شرق آسيا في القرن 12",
    "القرن 12 في جورجيا": "جورجيا في القرن 12",
    "القرن 12 في روسيا": "روسيا في القرن 12",
    "القرن 12 في رومانيا": "رومانيا في القرن 12",
    "القرن 12 في سريلانكا": "سريلانكا في القرن 12",
    "القرن 12 في سكونا (السويد)": "سكونا (السويد) في القرن 12",
    "القرن 12 في سلاجقة الروم": "سلاجقة الروم في القرن 12",
    "القرن 12 في سوريا": "سوريا في القرن 12",
    "القرن 12 في صربيا": "صربيا في القرن 12",
    "القرن 12 في فنلندا": "فنلندا في القرن 12",
    "القرن 12 في فيتنام": "فيتنام في القرن 12",
    "القرن 12 في قبرص": "قبرص في القرن 12",
    "القرن 12 في كرواتيا": "كرواتيا في القرن 12",
    "القرن 12 في كمبوديا": "كمبوديا في القرن 12",
    "القرن 12 في كوريا": "كوريا في القرن 12",
    "القرن 12 في كييف روس": "كييف روس في القرن 12",
    "القرن 12 في لندن": "لندن في القرن 12",
    "القرن 12 في مالطا": "مالطا في القرن 12",
    "القرن 12 في ماليزيا": "ماليزيا في القرن 12",
    "القرن 12 في مايا": "مايا في القرن 12",
    "القرن 12 في مصر": "مصر في القرن 12",
    "القرن 12 في مملكة جورجيا": "مملكة جورجيا في القرن 12",
    "القرن 12 في مملكة صقلية": "مملكة صقلية في القرن 12",
    "القرن 12 في مملكة ليون": "مملكة ليون في القرن 12",
    "القرن 12 في أرغون": "أرغون في القرن 12",
    "القرن 12 في منغوليا": "منغوليا في القرن 12",
    "القرن 12 في نيبال": "نيبال في القرن 12",
    "القرن 12 في نيجيريا": "نيجيريا في القرن 12",
    "القرن 12 في هولندا": "هولندا في القرن 12",
    "القرن 12 في يورك": "يورك في القرن 12",
    "القرن 12 في يوركشاير": "يوركشاير في القرن 12",
    "القرن 12 ق م في الصين": "الصين في القرن 12 ق م",
    "القرن 12 ق م في اليونان": "اليونان في القرن 12 ق م",
    "القرن 12 ق م في مصر": "مصر في القرن 12 ق م",
    "القرن 13 في أندورا": "أندورا في القرن 13",
    "القرن 13 في قبرص": "قبرص في القرن 13",
    "القرن 13 في كتالونيا": "كتالونيا في القرن 13",
    "عقد 0 في الإمبراطورية الرومانية": "الإمبراطورية الرومانية في عقد 0",
    "عقد 0 ق م في الإمبراطورية الرومانية": "الإمبراطورية الرومانية في عقد 0 ق م",
    "عقد 10 في الإمبراطورية الرومانية": "الإمبراطورية الرومانية في عقد 10",
    "عقد 10 ق م في الإمبراطورية الرومانية": "الإمبراطورية الرومانية في عقد 10 ق م",
    "عقد 100 في الإمبراطورية الرومانية": "الإمبراطورية الرومانية في عقد 100",
    "عقد 1000 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1000",
    "عقد 1000 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1000",
    "عقد 1000 في الفنون": "الفنون في عقد 1000",
    "عقد 1000 في اليابان": "اليابان في عقد 1000",
    "عقد 1010 في فرنسا": "فرنسا في عقد 1010",
    "عقد 1020 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1020",
    "عقد 1020 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1020",
    "عقد 1020 في الفنون": "الفنون في عقد 1020",
    "عقد 1020 في اليابان": "اليابان في عقد 1020",
    "عقد 1020 في فرنسا": "فرنسا في عقد 1020",
    "عقد 1030 في آسيا": "آسيا في عقد 1030",
    "عقد 1030 في أوروبا": "أوروبا في عقد 1030",
    "عقد 1030 في إنجلترا": "إنجلترا في عقد 1030",
    "عقد 1030 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1030",
    "عقد 1030 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1030",
    "عقد 1030 في الفنون": "الفنون في عقد 1030",
    "عقد 1030 في اليابان": "اليابان في عقد 1030",
    "عقد 1030 في فرنسا": "فرنسا في عقد 1030",
    "عقد 1050 في آسيا": "آسيا في عقد 1050",
    "عقد 1050 في إسكتلندا": "إسكتلندا في عقد 1050",
    "عقد 1050 في إنجلترا": "إنجلترا في عقد 1050",
    "عقد 1050 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1050",
    "عقد 1050 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1050",
    "عقد 1050 في الفنون": "الفنون في عقد 1050",
    "عقد 1050 في اليابان": "اليابان في عقد 1050",
    "عقد 1050 في فرنسا": "فرنسا في عقد 1050",
    "عقد 1070 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1070",
    "عقد 1070 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1070",
    "عقد 1070 في الفنون": "الفنون في عقد 1070",
    "عقد 1070 في اليابان": "اليابان في عقد 1070",
    "عقد 1070 في فرنسا": "فرنسا في عقد 1070",
    "عقد 1080 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1080",
    "عقد 1080 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1080",
    "عقد 1080 في الفنون": "الفنون في عقد 1080",
    "عقد 1080 في اليابان": "اليابان في عقد 1080",
    "عقد 1080 في فرنسا": "فرنسا في عقد 1080",
    "عقد 1090 في إسكتلندا": "إسكتلندا في عقد 1090",
    "عقد 1090 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1090",
    "عقد 1090 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1090",
    "عقد 1090 في الفنون": "الفنون في عقد 1090",
    "عقد 1090 في اليابان": "اليابان في عقد 1090",
    "عقد 1090 في فرنسا": "فرنسا في عقد 1090",
    "عقد 1090 في مملكة القدس": "مملكة القدس في عقد 1090",
    "عقد 1410 في البرتغال": "البرتغال في عقد 1410",
    "عقد 1410 في ويلز": "ويلز في عقد 1410",
    "عقد 1420 في أمريكا الشمالية": "أمريكا الشمالية في عقد 1420",
    "عقد 1420 في أيرلندا": "أيرلندا في عقد 1420",
    "عقد 1420 في الأراضي المنخفضة البورغندية": "الأراضي المنخفضة البورغندية في عقد 1420",
    "عقد 1420 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1420",
    "عقد 1420 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1420",
    "عقد 1420 في الدنمارك": "الدنمارك في عقد 1420",
    "عقد 1420 في الدولة العثمانية": "الدولة العثمانية في عقد 1420",
    "عقد 1420 في الشرق الأوسط": "الشرق الأوسط في عقد 1420",
    "عقد 1420 في اليابان": "اليابان في عقد 1420",
    "عقد 1420 في فرنسا": "فرنسا في عقد 1420",
    "عقد 1430 في أيرلندا": "أيرلندا في عقد 1430",
    "عقد 1430 في الأراضي المنخفضة البورغندية": "الأراضي المنخفضة البورغندية في عقد 1430",
    "عقد 1430 في الدنمارك": "الدنمارك في عقد 1430",
    "عقد 1430 في بوتان": "بوتان في عقد 1430",
}
move_by_in_data = {
    "أمريكيون حسب المهنة في القرن 20": "أمريكيون في القرن 20 حسب المهنة",
    "ملكيون حسب البلد في القرن 20": "ملكيون في القرن 20 حسب البلد",
    "ممثلون حسب الدين في القرن 19": "ممثلون في القرن 19 حسب الدين",
    "أشخاص حسب الدين في القرن 19": "أشخاص في القرن 19 حسب الدين",
    "كتاب غير روائيين حسب الجنسية في القرن 20": "كتاب غير روائيين في القرن 20 حسب الجنسية",
    "موسيقيون حسب الآلة من أيرلندا الشمالية في القرن 20": "موسيقيون في القرن 20 حسب الآلة من أيرلندا الشمالية",
    "آسيويون حسب الجنسية في القرن 10": "آسيويون في القرن 10 حسب الجنسية",
    "آسيويون حسب الجنسية في القرن 11": "آسيويون في القرن 11 حسب الجنسية",
    "آسيويون حسب الجنسية في القرن 12": "آسيويون في القرن 12 حسب الجنسية",
    "أساقفة حسب الجنسية في القرن 10": "أساقفة في القرن 10 حسب الجنسية",
    "أساقفة حسب الجنسية في القرن 11": "أساقفة في القرن 11 حسب الجنسية",
    "أساقفة حسب الجنسية في القرن 12": "أساقفة في القرن 12 حسب الجنسية",
    "أساقفة كاثوليك رومان حسب الجنسية في القرن 11": "أساقفة كاثوليك رومان في القرن 11 حسب الجنسية",
    "أشخاص حسب الجنسية في القرن 10 ق م": "أشخاص في القرن 10 ق م حسب الجنسية",
    "أشخاص حسب الجنسية في القرن 10": "أشخاص في القرن 10 حسب الجنسية",
    "أشخاص حسب الجنسية في القرن 11 ق م": "أشخاص في القرن 11 ق م حسب الجنسية",
    "أشخاص حسب الجنسية في القرن 11": "أشخاص في القرن 11 حسب الجنسية",
    "أشخاص حسب الجنسية في القرن 13 ق م": "أشخاص في القرن 13 ق م حسب الجنسية",
    "أشخاص حسب الجنسية والمهنة في القرن 10": "أشخاص في القرن 10 حسب الجنسية والمهنة",
    "أشخاص حسب الجنسية والمهنة في القرن 11": "أشخاص في القرن 11 حسب الجنسية والمهنة",
    "أشخاص حسب الدين في القرن 10": "أشخاص في القرن 10 حسب الدين",
    "أشخاص حسب الدين في القرن 11": "أشخاص في القرن 11 حسب الدين",
    "أشخاص حسب القارة في القرن 10": "أشخاص في القرن 10 حسب القارة",
    "أشخاص حسب القارة في القرن 11": "أشخاص في القرن 11 حسب القارة",
    "أشخاص حسب القارة في القرن 12": "أشخاص في القرن 12 حسب القارة",
    "أشخاص حسب المهنة في القرن 10 ق م": "أشخاص في القرن 10 ق م حسب المهنة",
    "أشخاص حسب المهنة في القرن 10": "أشخاص في القرن 10 حسب المهنة",
    "أشخاص حسب المهنة في القرن 11": "أشخاص في القرن 11 حسب المهنة",
    "أشخاص حسب المهنة والجنسية في القرن 10": "أشخاص في القرن 10 حسب المهنة والجنسية",
    "أشخاص حسب المهنة والجنسية في القرن 11": "أشخاص في القرن 11 حسب المهنة والجنسية",
    "أشخاص حسب النزاع في القرن 10": "أشخاص في القرن 10 حسب النزاع",
    "أشخاص حسب النزاع في القرن 11": "أشخاص في القرن 11 حسب النزاع",
    "أشخاص حسب النزاع في القرن 12": "أشخاص في القرن 12 حسب النزاع",
    "أفارقة حسب الجنسية في القرن 10": "أفارقة في القرن 10 حسب الجنسية",
    "أفارقة حسب الجنسية في القرن 11": "أفارقة في القرن 11 حسب الجنسية",
    "أفارقة حسب الجنسية في القرن 12": "أفارقة في القرن 12 حسب الجنسية",
    "ألمان حسب المهنة في القرن 13": "ألمان في القرن 13 حسب المهنة",
    "أوروبيون حسب الجنسية في القرن 10": "أوروبيون في القرن 10 حسب الجنسية",
    "أوروبيون حسب الجنسية في القرن 11": "أوروبيون في القرن 11 حسب الجنسية",
    "أوروبيون حسب الجنسية في القرن 12": "أوروبيون في القرن 12 حسب الجنسية",
    "إسبان حسب المهنة في القرن 10": "إسبان في القرن 10 حسب المهنة",
    "إسبان حسب المهنة في القرن 11": "إسبان في القرن 11 حسب المهنة",
    "إسبان حسب المهنة في القرن 12": "إسبان في القرن 12 حسب المهنة",
    "إسكتلنديون حسب المهنة في القرن 12": "إسكتلنديون في القرن 12 حسب المهنة",
    "إنجليز حسب المهنة في القرن 10": "إنجليز في القرن 10 حسب المهنة",
    "إنجليز حسب المهنة في القرن 11": "إنجليز في القرن 11 حسب المهنة",
    "إنجليز حسب المهنة في القرن 12": "إنجليز في القرن 12 حسب المهنة",
    "إيطاليون حسب المهنة في القرن 11": "إيطاليون في القرن 11 حسب المهنة",
    "إيطاليون حسب المهنة في القرن 12": "إيطاليون في القرن 12 حسب المهنة",
    "التاريخ العسكري حسب البلد في القرن 13": "التاريخ العسكري في القرن 13 حسب البلد",
    "المرأة حسب الجنسية في القرن 10 ق م": "المرأة في القرن 10 ق م حسب الجنسية",
    "المرأة حسب الجنسية في القرن 10": "المرأة في القرن 10 حسب الجنسية",
    "المرأة حسب الجنسية في القرن 11 ق م": "المرأة في القرن 11 ق م حسب الجنسية",
    "المرأة حسب الجنسية في القرن 11": "المرأة في القرن 11 حسب الجنسية",
    "المرأة حسب الجنسية في القرن 12 ق م": "المرأة في القرن 12 ق م حسب الجنسية",
    "المرأة حسب الجنسية في القرن 12": "المرأة في القرن 12 حسب الجنسية",
    "المرأة حسب الجنسية في القرن 13 ق م": "المرأة في القرن 13 ق م حسب الجنسية",
    "المرأة حسب المهنة في القرن 10": "المرأة في القرن 10 حسب المهنة",
    "المرأة حسب المهنة في القرن 11": "المرأة في القرن 11 حسب المهنة",
    "المرأة حسب المهنة في القرن 12": "المرأة في القرن 12 حسب المهنة",
    "رياضياتيون حسب الجنسية في القرن 11": "رياضياتيون في القرن 11 حسب الجنسية",
    "رياضياتيون حسب الجنسية في القرن 12": "رياضياتيون في القرن 12 حسب الجنسية",
    "رياضياتيون حسب الجنسية في القرن 13": "رياضياتيون في القرن 13 حسب الجنسية",
    "شخصيات أعمال حسب الجنسية في القرن 13": "شخصيات أعمال في القرن 13 حسب الجنسية",
    "صينيون حسب المهنة في القرن 10": "صينيون في القرن 10 حسب المهنة",
    "صينيون حسب المهنة في القرن 11": "صينيون في القرن 11 حسب المهنة",
    "صينيون حسب المهنة في القرن 12": "صينيون في القرن 12 حسب المهنة",
    "عقود حسب البلد في القرن 10": "عقود في القرن 10 حسب البلد",
    "عقود حسب البلد في القرن 11": "عقود في القرن 11 حسب البلد",
    "علماء حسب الجنسية في القرن 12": "علماء في القرن 12 حسب الجنسية",
    "فرنسيون حسب المهنة في القرن 12": "فرنسيون في القرن 12 حسب المهنة",
    "فلاسفة حسب الجنسية في القرن 10": "فلاسفة في القرن 10 حسب الجنسية",
    "فلاسفة حسب الجنسية في القرن 11": "فلاسفة في القرن 11 حسب الجنسية",
    "فلاسفة حسب الجنسية في القرن 12": "فلاسفة في القرن 12 حسب الجنسية",
    "فلكيون حسب الجنسية في القرن 13": "فلكيون في القرن 13 حسب الجنسية",
    "فنانون حسب الجنسية في القرن 10": "فنانون في القرن 10 حسب الجنسية",
    "فنانون حسب الجنسية في القرن 11": "فنانون في القرن 11 حسب الجنسية",
    "فنانون حسب الجنسية في القرن 12": "فنانون في القرن 12 حسب الجنسية",
    "كنائس حسب البلد في القرن 10": "كنائس في القرن 10 حسب البلد",
    "كنائس حسب البلد في القرن 11": "كنائس في القرن 11 حسب البلد",
    "كنائس حسب البلد في القرن 12": "كنائس في القرن 12 حسب البلد",
    "كوريون حسب المهنة في القرن 10": "كوريون في القرن 10 حسب المهنة",
    "كوريون حسب المهنة في القرن 11": "كوريون في القرن 11 حسب المهنة",
    "كوريون حسب المهنة في القرن 12": "كوريون في القرن 12 حسب المهنة",
    "مؤرخون حسب الجنسية في القرن 10": "مؤرخون في القرن 10 حسب الجنسية",
    "مؤرخون حسب الجنسية في القرن 11": "مؤرخون في القرن 11 حسب الجنسية",
    "مؤرخون حسب الجنسية في القرن 12": "مؤرخون في القرن 12 حسب الجنسية",
    "مؤرخون حسب الجنسية في القرن 13": "مؤرخون في القرن 13 حسب الجنسية",
    "مبان كنائس رومانية كاثوليكية حسب البلد في القرن 11": "مبان كنائس رومانية كاثوليكية في القرن 11 حسب البلد",
    "مبان كنائس رومانية كاثوليكية حسب البلد في القرن 12": "مبان كنائس رومانية كاثوليكية في القرن 12 حسب البلد",
    "مبان ومنشآت دينية حسب البلد في القرن 12": "مبان ومنشآت دينية في القرن 12 حسب البلد",
    "ملكيون حسب البلد في القرن 10": "ملكيون في القرن 10 حسب البلد",
    "ملكيون حسب البلد في القرن 11": "ملكيون في القرن 11 حسب البلد",
    "ملكيون حسب البلد في القرن 12": "ملكيون في القرن 12 حسب البلد",
    "موسيقيون حسب الجنسية في القرن 11": "موسيقيون في القرن 11 حسب الجنسية",
    "موسيقيون حسب الجنسية في القرن 12": "موسيقيون في القرن 12 حسب الجنسية",
    "هنود حسب المهنة في القرن 10": "هنود في القرن 10 حسب المهنة",
    "هنود حسب المهنة في القرن 11": "هنود في القرن 11 حسب المهنة",
    "هنود حسب المهنة في القرن 12": "هنود في القرن 12 حسب المهنة",
    "يابانيون حسب المهنة في القرن 10": "يابانيون في القرن 10 حسب المهنة",
    "يابانيون حسب المهنة في القرن 11": "يابانيون في القرن 11 حسب المهنة",
    "يابانيون حسب المهنة في القرن 12": "يابانيون في القرن 12 حسب المهنة",
    "يهود حسب الجنسية في القرن 11": "يهود في القرن 11 حسب الجنسية",
    "يهود حسب الجنسية في القرن 12": "يهود في القرن 12 حسب الجنسية",
    "يونانيون حسب المهنة في القرن 10": "يونانيون في القرن 10 حسب المهنة",
    "يونانيون حسب المهنة في القرن 11": "يونانيون في القرن 11 حسب المهنة",
    "يونانيون حسب المهنة في القرن 13": "يونانيون في القرن 13 حسب المهنة",
}

to_test = [
    ("test_move_years_first", move_years_first_data, move_years_first),
    ("test_move_by_in", move_by_in_data, move_by_in),
]


@pytest.mark.parametrize("category, expected", move_years_first_data.items(), ids=move_years_first_data.keys())
@pytest.mark.fast
def test_move_years_first(category: str, expected: str) -> None:
    label = move_years_first(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", move_by_in_data.items(), ids=move_by_in_data.keys())
@pytest.mark.fast
def test_move_by_in(category: str, expected: str) -> None:
    label = move_by_in(category)
    assert label == expected


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#
import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar

test_c_musicians_1 = {
    "LGBTQ classical musicians": "موسيقيون كلاسيكيون مثليون",
    "Classical musicians with disabilities": "موسيقيون كلاسيكيون بإعاقات",
    "Croatian classical musicians by instrument": "موسيقيون كلاسيكيون كروات حسب الآلة",
    "Croatian classical musicians": "موسيقيون كلاسيكيون كروات",
    "Families of classical musicians": "عائلات موسيقيون كلاسيكيون",
}

test_c_musicians_3 = {
    "16th-century classical musicians": "موسيقيون كلاسيكيون في القرن 16",
    "17th-century classical musicians": "موسيقيون كلاسيكيون في القرن 17",
    "18th-century classical musicians": "موسيقيون كلاسيكيون في القرن 18",
    "19th-century classical musicians": "موسيقيون كلاسيكيون في القرن 19",
    "20th-century classical musicians from Northern Ireland": "موسيقيون كلاسيكيون من أيرلندا الشمالية في القرن 20",
    "20th-century classical musicians": "موسيقيون كلاسيكيون في القرن 20",
    "21st-century classical musicians from Northern Ireland": "موسيقيون كلاسيكيون من أيرلندا الشمالية في القرن 21",
    "21st-century classical musicians": "موسيقيون كلاسيكيون في القرن 21",
    "Albanian classical musicians": "موسيقيون كلاسيكيون ألبان",
    "Algerian classical musicians": "موسيقيون كلاسيكيون جزائريون",
    "American classical musicians by instrument": "موسيقيون كلاسيكيون أمريكيون حسب الآلة",
    "American classical musicians by state": "موسيقيون كلاسيكيون أمريكيون حسب الولاية",
    "American classical musicians of Asian descent": "موسيقيون كلاسيكيون أمريكيون من أصل آسيوي",
    "American classical musicians of Chinese descent": "موسيقيون كلاسيكيون أمريكيون من أصل صيني",
    "American classical musicians of Japanese descent": "موسيقيون كلاسيكيون أمريكيون من أصل ياباني",
    "American classical musicians of Korean descent": "موسيقيون كلاسيكيون أمريكيون من أصل كوري",
    "American classical musicians": "موسيقيون كلاسيكيون أمريكيون",
    "American contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون أمريكيون",
    "Argentine classical musicians by instrument": "موسيقيون كلاسيكيون أرجنتينيون حسب الآلة",
    "Argentine classical musicians": "موسيقيون كلاسيكيون أرجنتينيون",
    "Australian classical musicians by instrument": "موسيقيون كلاسيكيون أستراليون حسب الآلة",
    "Australian classical musicians": "موسيقيون كلاسيكيون أستراليون",
    "Austrian classical musicians by instrument": "موسيقيون كلاسيكيون نمساويون حسب الآلة",
    "Austrian classical musicians": "موسيقيون كلاسيكيون نمساويون",
    "Azerbaijani classical musicians by instrument": "موسيقيون كلاسيكيون أذربيجانيون حسب الآلة",
    "Azerbaijani classical musicians": "موسيقيون كلاسيكيون أذربيجانيون",
    "Belgian classical musicians by instrument": "موسيقيون كلاسيكيون بلجيكيون حسب الآلة",
    "Belgian classical musicians": "موسيقيون كلاسيكيون بلجيكيون",
    "Bolivian classical musicians by instrument": "موسيقيون كلاسيكيون بوليفيون حسب الآلة",
    "Bolivian classical musicians": "موسيقيون كلاسيكيون بوليفيون",
    "Bosnia and Herzegovina classical musicians": "موسيقيون كلاسيكيون بوسنيون",
    "Brazilian classical musicians by instrument": "موسيقيون كلاسيكيون برازيليون حسب الآلة",
    "Brazilian classical musicians": "موسيقيون كلاسيكيون برازيليون",
    "British classical musicians by instrument": "موسيقيون كلاسيكيون بريطانيون حسب الآلة",
    "British classical musicians": "موسيقيون كلاسيكيون بريطانيون",
    "British contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون بريطانيون",
    "Bulgarian classical musicians by instrument": "موسيقيون كلاسيكيون بلغاريون حسب الآلة",
    "Bulgarian classical musicians": "موسيقيون كلاسيكيون بلغاريون",
    "Canadian classical musicians by instrument": "موسيقيون كلاسيكيون كنديون حسب الآلة",
    "Canadian classical musicians": "موسيقيون كلاسيكيون كنديون",
    "Canadian contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون كنديون",
    "Child classical musicians": "موسيقيون كلاسيكيون أطفال",
    "Chilean classical musicians": "موسيقيون كلاسيكيون تشيليون",
    "Chinese classical musicians by instrument": "موسيقيون كلاسيكيون صينيون حسب الآلة",
    "Chinese classical musicians": "موسيقيون كلاسيكيون صينيون",
    "Classical musicians by ethnicity": "موسيقيون كلاسيكيون حسب المجموعة العرقية",
    "Classical musicians by genre": "موسيقيون كلاسيكيون حسب النوع الفني",
    "Classical musicians by instrument and nationality": "موسيقيون كلاسيكيون حسب الآلة والجنسية",
    "Classical musicians by instrument": "موسيقيون كلاسيكيون حسب الآلة",
    "Classical musicians by nationality and instrument": "موسيقيون كلاسيكيون حسب الجنسية والآلة",
    "Classical musicians by nationality": "موسيقيون كلاسيكيون حسب الجنسية",
    "Classical musicians from Arkansas": "موسيقيون كلاسيكيون من أركنساس",
    "Classical musicians from California": "موسيقيون كلاسيكيون من كاليفورنيا",
    "Classical musicians from Catalonia": "موسيقيون كلاسيكيون من كتالونيا",
    "Classical musicians from Colorado": "موسيقيون كلاسيكيون من كولورادو",
    "Classical musicians from Connecticut": "موسيقيون كلاسيكيون من كونيتيكت",
    "Classical musicians from Florida": "موسيقيون كلاسيكيون من فلوريدا",
    "Classical musicians from Georgia (country) by instrument": "موسيقيون كلاسيكيون من جورجيا حسب الآلة",
    "Classical musicians from Georgia (country)": "موسيقيون كلاسيكيون من جورجيا",
    "Classical musicians from Georgia (U.S. state)": "موسيقيون كلاسيكيون من ولاية جورجيا",
    "Classical musicians from Illinois": "موسيقيون كلاسيكيون من إلينوي",
    "Classical musicians from Indiana": "موسيقيون كلاسيكيون من إنديانا",
    "Classical musicians from Iowa": "موسيقيون كلاسيكيون من آيوا",
    "Classical musicians from Kansas": "موسيقيون كلاسيكيون من كانساس",
    "Classical musicians from Louisiana": "موسيقيون كلاسيكيون من لويزيانا",
    "Classical musicians from Maryland": "موسيقيون كلاسيكيون من ماريلند",
    "Classical musicians from Massachusetts": "موسيقيون كلاسيكيون من ماساتشوستس",
    "Classical musicians from Michigan": "موسيقيون كلاسيكيون من ميشيغان",
    "Classical musicians from Minnesota": "موسيقيون كلاسيكيون من منيسوتا",
    "Classical musicians from Mississippi": "موسيقيون كلاسيكيون من مسيسيبي",
    "Classical musicians from Missouri": "موسيقيون كلاسيكيون من ميزوري",
    "Classical musicians from Nebraska": "موسيقيون كلاسيكيون من نبراسكا",
    "Classical musicians from New Jersey": "موسيقيون كلاسيكيون من نيوجيرسي",
    "Classical musicians from New York (state)": "موسيقيون كلاسيكيون من ولاية نيويورك",
    "Classical musicians from North Carolina": "موسيقيون كلاسيكيون من كارولاينا الشمالية",
    "Classical musicians from Northern Ireland by instrument": "موسيقيون كلاسيكيون من أيرلندا الشمالية حسب الآلة",
    "Classical musicians from Northern Ireland": "موسيقيون كلاسيكيون من أيرلندا الشمالية",
    "Classical musicians from Ohio": "موسيقيون كلاسيكيون من أوهايو",
    "Classical musicians from Oklahoma": "موسيقيون كلاسيكيون من أوكلاهوما",
    "Classical musicians from Pennsylvania": "موسيقيون كلاسيكيون من بنسلفانيا",
    "Classical musicians from Rhode Island": "موسيقيون كلاسيكيون من رود آيلاند",
    "Classical musicians from South Carolina": "موسيقيون كلاسيكيون من كارولاينا الجنوبية",
    "Classical musicians from South Dakota": "موسيقيون كلاسيكيون من داكوتا الجنوبية",
    "Classical musicians from Tennessee": "موسيقيون كلاسيكيون من تينيسي",
    "Classical musicians from Texas": "موسيقيون كلاسيكيون من تكساس",
    "Classical musicians from Vermont": "موسيقيون كلاسيكيون من فيرمونت",
    "Classical musicians from Virginia": "موسيقيون كلاسيكيون من فرجينيا",
    "Classical musicians from Washington, D.C.": "موسيقيون كلاسيكيون من واشنطن العاصمة",
    "Classical musicians from Wisconsin": "موسيقيون كلاسيكيون من ويسكونسن",
    "Classical musicians": "موسيقيون كلاسيكيون",
    "Colombian classical musicians by instrument": "موسيقيون كلاسيكيون كولومبيون حسب الآلة",
    "Colombian classical musicians": "موسيقيون كلاسيكيون كولومبيون",
    "Contemporary classical musicians by nationality": "موسيقيون كلاسيكيون معاصرون حسب الجنسية",
    "Contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون",
    "Cuban classical musicians": "موسيقيون كلاسيكيون كوبيون",
    "Czech classical musicians by instrument": "موسيقيون كلاسيكيون تشيكيون حسب الآلة",
    "Czech classical musicians": "موسيقيون كلاسيكيون تشيكيون",
    "Czechoslovak classical musicians": "موسيقيون كلاسيكيون تشيكوسلوفاكيون",
    "Danish classical musicians by instrument": "موسيقيون كلاسيكيون دنماركيون حسب الآلة",
    "Danish classical musicians": "موسيقيون كلاسيكيون دنماركيون",
    "Deaf classical musicians": "موسيقيون كلاسيكيون صم",
    "Dutch classical musicians by instrument": "موسيقيون كلاسيكيون هولنديون حسب الآلة",
    "Dutch classical musicians": "موسيقيون كلاسيكيون هولنديون",
    "Ecuadorian classical musicians by instrument": "موسيقيون كلاسيكيون إكوادوريون حسب الآلة",
    "Ecuadorian classical musicians": "موسيقيون كلاسيكيون إكوادوريون",
    "Egyptian classical musicians": "موسيقيون كلاسيكيون مصريون",
    "English classical musicians by instrument": "موسيقيون كلاسيكيون إنجليز حسب الآلة",
    "English classical musicians": "موسيقيون كلاسيكيون إنجليز",
    "English contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون إنجليز",
    "Estonian classical musicians by instrument": "موسيقيون كلاسيكيون إستونيون حسب الآلة",
    "Estonian classical musicians": "موسيقيون كلاسيكيون إستونيون",
    "Filipino classical musicians by instrument": "موسيقيون كلاسيكيون فلبينيون حسب الآلة",
    "Filipino classical musicians": "موسيقيون كلاسيكيون فلبينيون",
    "Finnish classical musicians by instrument": "موسيقيون كلاسيكيون فنلنديون حسب الآلة",
    "Finnish classical musicians": "موسيقيون كلاسيكيون فنلنديون",
    "French classical musicians by instrument": "موسيقيون كلاسيكيون فرنسيون حسب الآلة",
    "French classical musicians": "موسيقيون كلاسيكيون فرنسيون",
    "German classical musicians by instrument": "موسيقيون كلاسيكيون ألمان حسب الآلة",
    "German classical musicians": "موسيقيون كلاسيكيون ألمان",
    "German contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون ألمان",
    "Greek classical musicians by instrument": "موسيقيون كلاسيكيون يونانيون حسب الآلة",
    "Greek classical musicians": "موسيقيون كلاسيكيون يونانيون",
    "Guatemalan classical musicians": "موسيقيون كلاسيكيون غواتيماليون",
    "Haitian classical musicians": "موسيقيون كلاسيكيون هايتيون",
    "Hong Kong classical musicians": "موسيقيون كلاسيكيون هونغ كونغيون",
    "Hungarian classical musicians by instrument": "موسيقيون كلاسيكيون مجريون حسب الآلة",
    "Hungarian classical musicians": "موسيقيون كلاسيكيون مجريون",
    "Indian women classical musicians": "موسيقيات كلاسيكيات هنديات",
    "Iranian classical musicians": "موسيقيون كلاسيكيون إيرانيون",
    "Irish classical musicians by instrument": "موسيقيون كلاسيكيون أيرلنديون حسب الآلة",
    "Irish classical musicians": "موسيقيون كلاسيكيون أيرلنديون",
    "Israeli classical musicians by instrument": "موسيقيون كلاسيكيون إسرائيليون حسب الآلة",
    "Israeli classical musicians": "موسيقيون كلاسيكيون إسرائيليون",
    "Italian classical musicians by instrument": "موسيقيون كلاسيكيون إيطاليون حسب الآلة",
    "Italian classical musicians": "موسيقيون كلاسيكيون إيطاليون",
    "Japanese classical musicians by instrument": "موسيقيون كلاسيكيون يابانيون حسب الآلة",
    "Japanese classical musicians": "موسيقيون كلاسيكيون يابانيون",
    "Japanese contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون يابانيون",
    "Jewish American classical musicians": "موسيقيون كلاسيكيون أمريكيون يهود",
    "Jewish classical musicians": "موسيقيون كلاسيكيون يهود",
    "Korean classical musicians": "موسيقيون كلاسيكيون كوريون",
    "Latvian classical musicians by instrument": "موسيقيون كلاسيكيون لاتفيون حسب الآلة",
    "Latvian classical musicians": "موسيقيون كلاسيكيون لاتفيون",
    "Lebanese classical musicians by instrument": "موسيقيون كلاسيكيون لبنانيون حسب الآلة",
    "Lebanese classical musicians": "موسيقيون كلاسيكيون لبنانيون",
    "Lithuanian classical musicians by instrument": "موسيقيون كلاسيكيون ليتوانيون حسب الآلة",
    "Lithuanian classical musicians": "موسيقيون كلاسيكيون ليتوانيون",
    "Maltese classical musicians": "موسيقيون كلاسيكيون مالطيون",
    "Mexican classical musicians by instrument": "موسيقيون كلاسيكيون مكسيكيون حسب الآلة",
    "Mexican classical musicians": "موسيقيون كلاسيكيون مكسيكيون",
    "New Zealand classical musicians by instrument": "موسيقيون كلاسيكيون نيوزيلنديون حسب الآلة",
    "New Zealand classical musicians": "موسيقيون كلاسيكيون نيوزيلنديون",
    "Norwegian classical musicians by instrument": "موسيقيون كلاسيكيون نرويجيون حسب الآلة",
    "Norwegian classical musicians": "موسيقيون كلاسيكيون نرويجيون",
    "Norwegian contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون نرويجيون",
    "Pakistani classical musicians": "موسيقيون كلاسيكيون باكستانيون",
    "Peruvian classical musicians": "موسيقيون كلاسيكيون بيرويون",
    "Polish classical musicians by instrument": "موسيقيون كلاسيكيون بولنديون حسب الآلة",
    "Polish classical musicians": "موسيقيون كلاسيكيون بولنديون",
    "Portuguese classical musicians by instrument": "موسيقيون كلاسيكيون برتغاليون حسب الآلة",
    "Portuguese classical musicians": "موسيقيون كلاسيكيون برتغاليون",
    "Puerto Rican classical musicians": "موسيقيون كلاسيكيون بورتوريكيون",
    "Russian classical musicians by instrument": "موسيقيون كلاسيكيون روس حسب الآلة",
    "Russian classical musicians": "موسيقيون كلاسيكيون روس",
    "Scottish classical musicians by instrument": "موسيقيون كلاسيكيون إسكتلنديون حسب الآلة",
    "Scottish classical musicians": "موسيقيون كلاسيكيون إسكتلنديون",
    "Serbian classical musicians by instrument": "موسيقيون كلاسيكيون صرب حسب الآلة",
    "Serbian classical musicians": "موسيقيون كلاسيكيون صرب",
    "Singaporean classical musicians by instrument": "موسيقيون كلاسيكيون سنغافوريون حسب الآلة",
    "Singaporean classical musicians": "موسيقيون كلاسيكيون سنغافوريون",
    "Slovak classical musicians": "موسيقيون كلاسيكيون سلوفاكيون",
    "Slovenian classical musicians": "موسيقيون كلاسيكيون سلوفينيون",
    "South Korean classical musicians by instrument": "موسيقيون كلاسيكيون كوريون جنوبيون حسب الآلة",
    "South Korean classical musicians": "موسيقيون كلاسيكيون كوريون جنوبيون",
    "Soviet classical musicians": "موسيقيون كلاسيكيون سوفيت",
    "Spanish classical musicians by instrument": "موسيقيون كلاسيكيون إسبان حسب الآلة",
    "Spanish classical musicians": "موسيقيون كلاسيكيون إسبان",
    "Swedish classical musicians by instrument": "موسيقيون كلاسيكيون سويديون حسب الآلة",
    "Swedish classical musicians": "موسيقيون كلاسيكيون سويديون",
    "Swiss classical musicians by instrument": "موسيقيون كلاسيكيون سويسريون حسب الآلة",
    "Swiss classical musicians": "موسيقيون كلاسيكيون سويسريون",
    "Taiwanese classical musicians": "موسيقيون كلاسيكيون تايوانيون",
    "Turkish classical musicians by instrument": "موسيقيون كلاسيكيون أتراك حسب الآلة",
    "Turkish classical musicians": "موسيقيون كلاسيكيون أتراك",
    "Ukrainian classical musicians by instrument": "موسيقيون كلاسيكيون أوكرانيون حسب الآلة",
    "Ukrainian classical musicians": "موسيقيون كلاسيكيون أوكرانيون",
    "Uruguayan classical musicians by instrument": "موسيقيون كلاسيكيون أوروغويانيون حسب الآلة",
    "Uruguayan classical musicians": "موسيقيون كلاسيكيون أوروغويانيون",
    "Venezuelan classical musicians by instrument": "موسيقيون كلاسيكيون فنزويليون حسب الآلة",
    "Venezuelan classical musicians": "موسيقيون كلاسيكيون فنزويليون",
    "Welsh classical musicians by instrument": "موسيقيون كلاسيكيون ويلزيون حسب الآلة",
    "Welsh classical musicians": "موسيقيون كلاسيكيون ويلزيون",
}

test_c_musicians_4 = {
    "18th-century British classical musicians": "موسيقيون كلاسيكيون بريطانيون في القرن 18",
    "18th-century Irish classical musicians": "موسيقيون كلاسيكيون أيرلنديون في القرن 18",
    "19th-century British classical musicians": "موسيقيون كلاسيكيون بريطانيون في القرن 19",
    "19th-century Irish classical musicians": "موسيقيون كلاسيكيون أيرلنديون في القرن 19",
    "20th-century American classical musicians": "موسيقيون كلاسيكيون أمريكيون في القرن 20",
    "20th-century Argentine classical musicians": "موسيقيون كلاسيكيون أرجنتينيون في القرن 20",
    "20th-century Armenian classical musicians": "موسيقيون كلاسيكيون أرمن في القرن 20",
    "20th-century Australian classical musicians": "موسيقيون كلاسيكيون أستراليون في القرن 20",
    "20th-century Austrian classical musicians": "موسيقيون كلاسيكيون نمساويون في القرن 20",
    "20th-century Belgian classical musicians": "موسيقيون كلاسيكيون بلجيكيون في القرن 20",
    "20th-century British classical musicians": "موسيقيون كلاسيكيون بريطانيون في القرن 20",
    "20th-century Canadian classical musicians": "موسيقيون كلاسيكيون كنديون في القرن 20",
    "20th-century classical musicians by nationality": "موسيقيون كلاسيكيون في القرن 20 حسب الجنسية",
    "20th-century Czech classical musicians": "موسيقيون كلاسيكيون تشيكيون في القرن 20",
    "20th-century Danish classical musicians": "موسيقيون كلاسيكيون دنماركيون في القرن 20",
    "20th-century Dutch classical musicians": "موسيقيون كلاسيكيون هولنديون في القرن 20",
    "20th-century English classical musicians": "موسيقيون كلاسيكيون إنجليز في القرن 20",
    "20th-century French classical musicians": "موسيقيون كلاسيكيون فرنسيون في القرن 20",
    "20th-century German classical musicians": "موسيقيون كلاسيكيون ألمان في القرن 20",
    "20th-century Hungarian classical musicians": "موسيقيون كلاسيكيون مجريون في القرن 20",
    "20th-century Irish classical musicians": "موسيقيون كلاسيكيون أيرلنديون في القرن 20",
    "20th-century Italian classical musicians": "موسيقيون كلاسيكيون إيطاليون في القرن 20",
    "20th-century Japanese classical musicians": "موسيقيون كلاسيكيون يابانيون في القرن 20",
    "20th-century Norwegian classical musicians": "موسيقيون كلاسيكيون نرويجيون في القرن 20",
    "20th-century Polish classical musicians": "موسيقيون كلاسيكيون بولنديون في القرن 20",
    "20th-century Russian classical musicians": "موسيقيون كلاسيكيون روس في القرن 20",
    "20th-century Spanish classical musicians": "موسيقيون كلاسيكيون إسبان في القرن 20",
    "20th-century Swedish classical musicians": "موسيقيون كلاسيكيون سويديون في القرن 20",
    "20th-century Swiss classical musicians": "موسيقيون كلاسيكيون سويسريون في القرن 20",
    "20th-century Turkish classical musicians": "موسيقيون كلاسيكيون أتراك في القرن 20",
    "21st-century American classical musicians": "موسيقيون كلاسيكيون أمريكيون في القرن 21",
    "21st-century British classical musicians": "موسيقيون كلاسيكيون بريطانيون في القرن 21",
    "21st-century French classical musicians": "موسيقيون كلاسيكيون فرنسيون في القرن 21",
    "21st-century German classical musicians": "موسيقيون كلاسيكيون ألمان في القرن 21",
    "21st-century Irish classical musicians": "موسيقيون كلاسيكيون أيرلنديون في القرن 21",
    "21st-century Japanese classical musicians": "موسيقيون كلاسيكيون يابانيون في القرن 21",
    "21st-century Norwegian classical musicians": "موسيقيون كلاسيكيون نرويجيون في القرن 21",
    "21st-century Russian classical musicians": "موسيقيون كلاسيكيون روس في القرن 21",
    "African-American classical musicians": "موسيقيون كلاسيكيون أمريكيون أفارقة",
    "American classical musicians by ethnicity": "موسيقيون كلاسيكيون أمريكيون حسب المجموعة العرقية",
    "American classical musicians of Indian descent": "موسيقيون كلاسيكيون أمريكيون من أصل هندي",
    "American male classical musicians": "موسيقيون كلاسيكيون ذكور أمريكيون",
    "American women classical musicians": "موسيقيات كلاسيكيات أمريكيات",
    "Armenian classical musicians by instrument": "موسيقيون كلاسيكيون أرمن حسب الآلة",
    "Armenian classical musicians": "موسيقيون كلاسيكيون أرمن",
    "Basque classical musicians": "موسيقيون كلاسيكيون باسكيون",
    "Belarusian classical musicians": "موسيقيون كلاسيكيون بيلاروسيون",
    "Blind classical musicians": "موسيقيون كلاسيكيون مكفوفون",
    "Canadian women classical musicians": "موسيقيات كلاسيكيات كنديات",
    "Classical musicians by century": "موسيقيون كلاسيكيون حسب القرن",
    "Classical musicians from Arizona": "موسيقيون كلاسيكيون من أريزونا",
    "Classical musicians from Maine": "موسيقيون كلاسيكيون من مين",
    "Classical musicians from Nevada": "موسيقيون كلاسيكيون من نيفادا",
    "Classical musicians from North Dakota": "موسيقيون كلاسيكيون من داكوتا الشمالية",
    "Classical musicians from Oregon": "موسيقيون كلاسيكيون من أوريغن",
    "Classical musicians from Washington (state)": "موسيقيون كلاسيكيون من ولاية واشنطن",
    "Classical musicians from West Virginia": "موسيقيون كلاسيكيون من فرجينيا الغربية",
    "French contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون فرنسيون",
    "Icelandic classical musicians by instrument": "موسيقيون كلاسيكيون آيسلنديون حسب الآلة",
    "Icelandic classical musicians": "موسيقيون كلاسيكيون آيسلنديون",
    "Indian classical musicians of Bengal": "موسيقيون كلاسيكيون هنود في البنغال",
    "Indian classical musicians": "موسيقيون كلاسيكيون هنود",
    "Indian male classical musicians": "موسيقيون كلاسيكيون ذكور هنود",
    "Irish women classical musicians": "موسيقيات كلاسيكيات أيرلنديات",
    "Luxembourgian classical musicians": "موسيقيون كلاسيكيون لوكسمبورغيون",
    "Moldovan classical musicians": "موسيقيون كلاسيكيون مولدوفيون",
    "Paraguayan classical musicians": "موسيقيون كلاسيكيون بارغوايانيون",
    "Romanian classical musicians by instrument": "موسيقيون كلاسيكيون رومان حسب الآلة",
    "Romanian classical musicians": "موسيقيون كلاسيكيون رومان",
    "Uzbekistani classical musicians": "موسيقيون كلاسيكيون أوزبكستانيون",
    "Women classical musicians by nationality": "موسيقيات كلاسيكيات حسب الجنسية",
    "Yugoslav classical musicians": "موسيقيون كلاسيكيون يوغسلافيون",
}

to_test = [
    ("test_classical_musicians_3", test_c_musicians_3),
    ("test_classical_musicians_4", test_c_musicians_4),
]


@pytest.mark.parametrize("category, expected", test_c_musicians_3.items(), ids=test_c_musicians_3.keys())
@pytest.mark.fast
def test_classical_musicians_3(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    # dump_same_and_not_same(data, diff_result, name, True)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
